import abc
import dataclasses
import functools
import re
from typing import Any, Dict, List, Optional, Pattern, Set, Tuple

from manubot.util import import_function

from .citekey import CiteKey

"""
Non-citation prefixes used by the pandoc-xnos suite of Pandoc filters,
including pandoc-fignos, pandoc-tablenos, pandoc-eqnos, and pandoc-secnos.
"""
_pandoc_xnos_prefixes: Set[str] = {"fig", "tbl", "eq", "sec"}


_local_handlers: List[str] = [
    "manubot.cite.arxiv.Handler_arXiv",
    "manubot.cite.doi.Handler_DOI",
    "manubot.cite.isbn.Handler_ISBN",
    "manubot.cite.pubmed.Handler_PMC",
    "manubot.cite.pubmed.Handler_PubMed",
    "manubot.cite.url.Handler_URL",
    "manubot.cite.wikidata.Handler_Wikidata",
]

_infer_prefix_patterns: List[Tuple[str, str]] = [
    ("doi", "accession_pattern"),
    ("doi", "shortdoi_pattern"),
    ("pmc", "accession_pattern"),
    ("pubmed", "accession_pattern"),
    ("wikidata", "accession_pattern"),
    ("arxiv", "accession_pattern"),
]
"""
Each list element is a tuple of (handler, pattern attribute).
Handler is the handler prefix (lowercase).
Pattern attribute refers to the Handler attribute containing a regex pattern.
A citekey prefix is inferred from the first matching pattern in this list.
"""


def infer_prefix(dealiased_id: str) -> Optional[str]:
    """
    Infer the prefix for citekey by matching it against a sequence of regexes.
    If a match is found, return the coressponding standard prefix.
    Otherwise, return None.
    """
    for prefix, pattern_attrib in _infer_prefix_patterns:
        handler = get_handler(prefix)
        pattern = handler._get_pattern(attribute=pattern_attrib)
        if pattern.fullmatch(dealiased_id):
            return handler.standard_prefix
    return None


@functools.lru_cache(maxsize=10_000)
def get_handler(prefix_lower: str) -> "Handler":
    if not isinstance(prefix_lower, str):
        raise TypeError(
            f"prefix_lower should be a str, instead received {prefix_lower.__class__.__name__}"
        )
    assert prefix_lower == prefix_lower.lower()
    handler = prefix_to_handler[prefix_lower]
    handler = import_function(handler)(prefix_lower)
    return handler


def _generate_prefix_to_handler() -> Dict[str, str]:
    """
    Generate complete dictionary for prefix_to_handler.
    """
    import inspect

    from .curie import get_curie_handlers

    curie_handlers = get_curie_handlers()
    pth = {}
    for handler in curie_handlers + _local_handlers:
        if isinstance(handler, str):
            handler = import_function(handler)("dummy_prefix_lower")
        for prefix in handler.prefixes:
            pth[
                prefix
            ] = f"{inspect.getmodule(handler).__name__}.{handler.__class__.__name__}"
    pth = dict(sorted(pth.items()))  # sort for clean diffs of serialized dict
    return pth


@dataclasses.dataclass
class Handler:
    """
    A Handler is a class that provides support for a certain type of citekey.
    For example, a Handler subclass could provide support for DOI citekeys.
    Subclasses enable custom logic for different citekey prefixes,
    including how to standardize the citekey and how to retrieve CSL Item metadata.
    """

    prefix_lower: str
    prefixes = []

    def _get_pattern(self, attribute: str = "accession_pattern") -> Optional[Pattern]:
        """
        Return a compiled regex pattern stored by `attribute`.
        By default, return `self.accession_pattern`, which Handler subclasses
        can set to provide the expected pattern for `self.accession`.
        """
        # todo: consider caching compilation
        pattern = getattr(self, attribute, None)
        if not pattern:
            return None
        if not isinstance(pattern, Pattern):
            pattern = re.compile(pattern)
        return pattern

    def inspect(self, citekey: CiteKey) -> Optional[str]:
        """
        Check citekeys adhere to expected formats. If an issue is detected a
        string describing the issue is returned. Otherwise returns None.
        """
        pattern = self._get_pattern("accession_pattern")
        if not pattern:
            return None
        if not pattern.fullmatch(citekey.accession):
            return f"{citekey.accession} does not match regex {pattern.pattern}"

    def standardize_prefix_accession(self, accession: str) -> Tuple[str, str]:
        """
        Return (prefix, accession) in standardized form.
        This method defaults to returning `self.standard_prefix`
        (or `self.prefix_lower` if standard_prefix is not defined).
        Subclasses can override this method with more specific standardization logic.
        """
        standard_prefix = getattr(self, "standard_prefix", self.prefix_lower)
        standard_accession = accession
        return standard_prefix, standard_accession

    @abc.abstractmethod
    def get_csl_item(self, citekey: CiteKey) -> Dict[str, Any]:
        """
        Return a CSL_Item with bibliographic details for citekey.
        """
        raise NotImplementedError(
            f"Manubot does not know how to generate a csl_item for {citekey.standard_id!r}"
        )


"""
Mapping from lowercase prefix to Handler class function location as string.
This output is automatically generated using `_generate_prefix_to_handler`.
Hardcoding this mapping reduces startup time and helps keep imports to a minimum,
allowing installations without the full dependencies to function.
"""
prefix_to_handler: Dict[str, str] = {
    "3dmet": "manubot.cite.curie.Handler_CURIE",
    "4dn": "manubot.cite.curie.Handler_CURIE",
    "4dn.biosource": "manubot.cite.curie.Handler_CURIE",
    "4dn.replicate": "manubot.cite.curie.Handler_CURIE",
    "aaindex": "manubot.cite.curie.Handler_CURIE",
    "aao": "manubot.cite.curie.Handler_CURIE",
    "abcd": "manubot.cite.curie.Handler_CURIE",
    "abm": "manubot.cite.curie.Handler_CURIE",
    "abs": "manubot.cite.curie.Handler_CURIE",
    "ac": "manubot.cite.curie.Handler_CURIE",
    "aceview.worm": "manubot.cite.curie.Handler_CURIE",
    "aclame": "manubot.cite.curie.Handler_CURIE",
    "addexbio": "manubot.cite.curie.Handler_CURIE",
    "addgene": "manubot.cite.curie.Handler_CURIE",
    "ado": "manubot.cite.curie.Handler_CURIE",
    "adw": "manubot.cite.curie.Handler_CURIE",
    "aeo": "manubot.cite.curie.Handler_CURIE",
    "aeo_retired": "manubot.cite.curie.Handler_CURIE",
    "aeon": "manubot.cite.curie.Handler_CURIE",
    "aero": "manubot.cite.curie.Handler_CURIE",
    "affy.probeset": "manubot.cite.curie.Handler_CURIE",
    "aftol.taxonomy": "manubot.cite.curie.Handler_CURIE",
    "agr": "manubot.cite.curie.Handler_CURIE",
    "agricola": "manubot.cite.curie.Handler_CURIE",
    "agricola_id": "manubot.cite.curie.Handler_CURIE",
    "agrkb": "manubot.cite.curie.Handler_CURIE",
    "agro": "manubot.cite.curie.Handler_CURIE",
    "agrovoc": "manubot.cite.curie.Handler_CURIE",
    "agsd": "manubot.cite.curie.Handler_CURIE",
    "aism": "manubot.cite.curie.Handler_CURIE",
    "alfred": "manubot.cite.curie.Handler_CURIE",
    "allergome": "manubot.cite.curie.Handler_CURIE",
    "alzforum.mutation": "manubot.cite.curie.Handler_CURIE",
    "alzforum_mut": "manubot.cite.curie.Handler_CURIE",
    "alzgene": "manubot.cite.curie.Handler_CURIE",
    "ama-cpt": "manubot.cite.curie.Handler_CURIE",
    "amoebadb": "manubot.cite.curie.Handler_CURIE",
    "amphx": "manubot.cite.curie.Handler_CURIE",
    "antibodyregistry": "manubot.cite.curie.Handler_CURIE",
    "antweb": "manubot.cite.curie.Handler_CURIE",
    "aop": "manubot.cite.curie.Handler_CURIE",
    "aop.events": "manubot.cite.curie.Handler_CURIE",
    "aop.relationships": "manubot.cite.curie.Handler_CURIE",
    "aop.stressor": "manubot.cite.curie.Handler_CURIE",
    "apaonto": "manubot.cite.curie.Handler_CURIE",
    "apd": "manubot.cite.curie.Handler_CURIE",
    "aphidbase.transcript": "manubot.cite.curie.Handler_CURIE",
    "apid.interactions": "manubot.cite.curie.Handler_CURIE",
    "apidb_plasmodb": "manubot.cite.curie.Handler_CURIE",
    "apo": "manubot.cite.curie.Handler_CURIE",
    "apollosv": "manubot.cite.curie.Handler_CURIE",
    "arachnoserver": "manubot.cite.curie.Handler_CURIE",
    "araport": "manubot.cite.curie.Handler_CURIE",
    "arba": "manubot.cite.curie.Handler_CURIE",
    "archdb": "manubot.cite.curie.Handler_CURIE",
    "ardb": "manubot.cite.curie.Handler_CURIE",
    "ark": "manubot.cite.curie.Handler_CURIE",
    "aro": "manubot.cite.curie.Handler_CURIE",
    "arrayexpress": "manubot.cite.curie.Handler_CURIE",
    "arrayexpress.platform": "manubot.cite.curie.Handler_CURIE",
    "arraymap": "manubot.cite.curie.Handler_CURIE",
    "arxiv": "manubot.cite.arxiv.Handler_arXiv",
    "asap": "manubot.cite.curie.Handler_CURIE",
    "ascl": "manubot.cite.curie.Handler_CURIE",
    "asin": "manubot.cite.curie.Handler_CURIE",
    "aspgd.locus": "manubot.cite.curie.Handler_CURIE",
    "aspgd.protein": "manubot.cite.curie.Handler_CURIE",
    "asrp": "manubot.cite.curie.Handler_CURIE",
    "astd": "manubot.cite.curie.Handler_CURIE",
    "atc": "manubot.cite.curie.Handler_CURIE",
    "atc_code": "manubot.cite.curie.Handler_CURIE",
    "atcc": "manubot.cite.curie.Handler_CURIE",
    "atcvet": "manubot.cite.curie.Handler_CURIE",
    "atfdb.family": "manubot.cite.curie.Handler_CURIE",
    "ato": "manubot.cite.curie.Handler_CURIE",
    "atol": "manubot.cite.curie.Handler_CURIE",
    "attc": "manubot.cite.curie.Handler_CURIE",
    "autdb": "manubot.cite.curie.Handler_CURIE",
    "bacdive": "manubot.cite.curie.Handler_CURIE",
    "bacmap.biog": "manubot.cite.curie.Handler_CURIE",
    "bacmap.map": "manubot.cite.curie.Handler_CURIE",
    "bactibase": "manubot.cite.curie.Handler_CURIE",
    "bao": "manubot.cite.curie.Handler_CURIE",
    "bartoc": "manubot.cite.curie.Handler_CURIE",
    "bbkg": "manubot.cite.curie.Handler_CURIE",
    "bbtp": "manubot.cite.curie.Handler_CURIE",
    "bcgo": "manubot.cite.curie.Handler_CURIE",
    "bcio": "manubot.cite.curie.Handler_CURIE",
    "bco": "manubot.cite.curie.Handler_CURIE",
    "bcrc": "manubot.cite.curie.Handler_CURIE",
    "bcrj": "manubot.cite.curie.Handler_CURIE",
    "bdgp.est": "manubot.cite.curie.Handler_CURIE",
    "bdgp.insertion": "manubot.cite.curie.Handler_CURIE",
    "bdsc": "manubot.cite.curie.Handler_CURIE",
    "beetlebase": "manubot.cite.curie.Handler_CURIE",
    "begdb": "manubot.cite.curie.Handler_CURIE",
    "bei_resources": "manubot.cite.curie.Handler_CURIE",
    "beiresources": "manubot.cite.curie.Handler_CURIE",
    "bfo": "manubot.cite.curie.Handler_CURIE",
    "bgee.family": "manubot.cite.curie.Handler_CURIE",
    "bgee.gene": "manubot.cite.curie.Handler_CURIE",
    "bgee.organ": "manubot.cite.curie.Handler_CURIE",
    "bgee.stage": "manubot.cite.curie.Handler_CURIE",
    "bibo": "manubot.cite.curie.Handler_CURIE",
    "bido": "manubot.cite.curie.Handler_CURIE",
    "bigg.compartment": "manubot.cite.curie.Handler_CURIE",
    "bigg.metabolite": "manubot.cite.curie.Handler_CURIE",
    "bigg.model": "manubot.cite.curie.Handler_CURIE",
    "bigg.reaction": "manubot.cite.curie.Handler_CURIE",
    "bila": "manubot.cite.curie.Handler_CURIE",
    "bind": "manubot.cite.curie.Handler_CURIE",
    "bindingdb": "manubot.cite.curie.Handler_CURIE",
    "biocarta.pathway": "manubot.cite.curie.Handler_CURIE",
    "biocatalogue.service": "manubot.cite.curie.Handler_CURIE",
    "biocyc": "manubot.cite.curie.Handler_CURIE",
    "biogrid": "manubot.cite.curie.Handler_CURIE",
    "biogrid.interaction": "manubot.cite.curie.Handler_CURIE",
    "biolegend": "manubot.cite.curie.Handler_CURIE",
    "biolink": "manubot.cite.curie.Handler_CURIE",
    "biomagresbank": "manubot.cite.curie.Handler_CURIE",
    "biomd": "manubot.cite.curie.Handler_CURIE",
    "biominder": "manubot.cite.curie.Handler_CURIE",
    "biomodels.db": "manubot.cite.curie.Handler_CURIE",
    "biomodels.kisao": "manubot.cite.curie.Handler_CURIE",
    "biomodels.teddy": "manubot.cite.curie.Handler_CURIE",
    "biomodels.vocabulary": "manubot.cite.curie.Handler_CURIE",
    "bionumbers": "manubot.cite.curie.Handler_CURIE",
    "biopixie": "manubot.cite.curie.Handler_CURIE",
    "bioportal": "manubot.cite.curie.Handler_CURIE",
    "bioproject": "manubot.cite.curie.Handler_CURIE",
    "bioregistry": "manubot.cite.curie.Handler_CURIE",
    "bioregistry.collection": "manubot.cite.curie.Handler_CURIE",
    "bioregistry.registry": "manubot.cite.curie.Handler_CURIE",
    "bioregistry.schema": "manubot.cite.curie.Handler_CURIE",
    "biorxiv": "manubot.cite.curie.Handler_CURIE",
    "biosample": "manubot.cite.curie.Handler_CURIE",
    "biosamples": "manubot.cite.curie.Handler_CURIE",
    "biosimulations": "manubot.cite.curie.Handler_CURIE",
    "biosimulators": "manubot.cite.curie.Handler_CURIE",
    "biostudies": "manubot.cite.curie.Handler_CURIE",
    "biosystems": "manubot.cite.curie.Handler_CURIE",
    "biotools": "manubot.cite.curie.Handler_CURIE",
    "biozil": "manubot.cite.curie.Handler_CURIE",
    "birdbase": "manubot.cite.curie.Handler_CURIE",
    "birnlex": "manubot.cite.curie.Handler_CURIE",
    "biro": "manubot.cite.curie.Handler_CURIE",
    "bitbucket": "manubot.cite.curie.Handler_CURIE",
    "bitterdb.cpd": "manubot.cite.curie.Handler_CURIE",
    "bitterdb.rec": "manubot.cite.curie.Handler_CURIE",
    "bko": "manubot.cite.curie.Handler_CURIE",
    "bmrb": "manubot.cite.curie.Handler_CURIE",
    "bmrb.restraint": "manubot.cite.curie.Handler_CURIE",
    "bold.taxonomy": "manubot.cite.curie.Handler_CURIE",
    "bootstrep": "manubot.cite.curie.Handler_CURIE",
    "bpdb": "manubot.cite.curie.Handler_CURIE",
    "brenda": "manubot.cite.curie.Handler_CURIE",
    "brenda.ligand": "manubot.cite.curie.Handler_CURIE",
    "brenda.ligandgroup": "manubot.cite.curie.Handler_CURIE",
    "broad": "manubot.cite.curie.Handler_CURIE",
    "bs": "manubot.cite.curie.Handler_CURIE",
    "bspo": "manubot.cite.curie.Handler_CURIE",
    "bto": "manubot.cite.curie.Handler_CURIE",
    "bugbase.expt": "manubot.cite.curie.Handler_CURIE",
    "bugbase.protocol": "manubot.cite.curie.Handler_CURIE",
    "bykdb": "manubot.cite.curie.Handler_CURIE",
    "c4o": "manubot.cite.curie.Handler_CURIE",
    "cabri": "manubot.cite.curie.Handler_CURIE",
    "cadsr": "manubot.cite.curie.Handler_CURIE",
    "caid": "manubot.cite.curie.Handler_CURIE",
    "caloha": "manubot.cite.curie.Handler_CURIE",
    "cameo": "manubot.cite.curie.Handler_CURIE",
    "caps": "manubot.cite.curie.Handler_CURIE",
    "caro": "manubot.cite.curie.Handler_CURIE",
    "cas": "manubot.cite.curie.Handler_CURIE",
    "cas_id": "manubot.cite.curie.Handler_CURIE",
    "cas_rn": "manubot.cite.curie.Handler_CURIE",
    "casid": "manubot.cite.curie.Handler_CURIE",
    "casspc": "manubot.cite.curie.Handler_CURIE",
    "cath": "manubot.cite.curie.Handler_CURIE",
    "cath.domain": "manubot.cite.curie.Handler_CURIE",
    "cath.superfamily": "manubot.cite.curie.Handler_CURIE",
    "cattleqtldb": "manubot.cite.curie.Handler_CURIE",
    "cazy": "manubot.cite.curie.Handler_CURIE",
    "cba": "manubot.cite.curie.Handler_CURIE",
    "cbioportal": "manubot.cite.curie.Handler_CURIE",
    "ccdc": "manubot.cite.curie.Handler_CURIE",
    "ccds": "manubot.cite.curie.Handler_CURIE",
    "ccle": "manubot.cite.curie.Handler_CURIE",
    "ccle.cell": "manubot.cite.curie.Handler_CURIE",
    "cco": "manubot.cite.curie.Handler_CURIE",
    "ccrid": "manubot.cite.curie.Handler_CURIE",
    "cdao": "manubot.cite.curie.Handler_CURIE",
    "cdd": "manubot.cite.curie.Handler_CURIE",
    "cdno": "manubot.cite.curie.Handler_CURIE",
    "cdpd": "manubot.cite.curie.Handler_CURIE",
    "cell_biolabs": "manubot.cite.curie.Handler_CURIE",
    "cell_model_passport": "manubot.cite.curie.Handler_CURIE",
    "cellbank.australia": "manubot.cite.curie.Handler_CURIE",
    "cellimage": "manubot.cite.curie.Handler_CURIE",
    "cellopub": "manubot.cite.curie.Handler_CURIE",
    "cellosaurus": "manubot.cite.curie.Handler_CURIE",
    "cellosaurus.resource": "manubot.cite.curie.Handler_CURIE",
    "cellrepo": "manubot.cite.curie.Handler_CURIE",
    "cemo": "manubot.cite.curie.Handler_CURIE",
    "ceph": "manubot.cite.curie.Handler_CURIE",
    "cgd": "manubot.cite.curie.Handler_CURIE",
    "cghdb": "manubot.cite.curie.Handler_CURIE",
    "cgnc": "manubot.cite.curie.Handler_CURIE",
    "cgsc": "manubot.cite.curie.Handler_CURIE",
    "charprot": "manubot.cite.curie.Handler_CURIE",
    "chebi": "manubot.cite.curie.Handler_CURIE",
    "chebiid": "manubot.cite.curie.Handler_CURIE",
    "chembank": "manubot.cite.curie.Handler_CURIE",
    "chembl": "manubot.cite.curie.Handler_CURIE",
    "chembl-cells": "manubot.cite.curie.Handler_CURIE",
    "chembl-targets": "manubot.cite.curie.Handler_CURIE",
    "chembl.cell": "manubot.cite.curie.Handler_CURIE",
    "chembl.compound": "manubot.cite.curie.Handler_CURIE",
    "chembl.target": "manubot.cite.curie.Handler_CURIE",
    "chembl_id": "manubot.cite.curie.Handler_CURIE",
    "chemdb": "manubot.cite.curie.Handler_CURIE",
    "chemidplus": "manubot.cite.curie.Handler_CURIE",
    "cheminf": "manubot.cite.curie.Handler_CURIE",
    "chemontid": "manubot.cite.curie.Handler_CURIE",
    "chemrof": "manubot.cite.curie.Handler_CURIE",
    "chemspider": "manubot.cite.curie.Handler_CURIE",
    "chemspiderid": "manubot.cite.curie.Handler_CURIE",
    "chickenqtldb": "manubot.cite.curie.Handler_CURIE",
    "chiro": "manubot.cite.curie.Handler_CURIE",
    "chmo": "manubot.cite.curie.Handler_CURIE",
    "cid": "manubot.cite.curie.Handler_CURIE",
    "cido": "manubot.cite.curie.Handler_CURIE",
    "cio": "manubot.cite.curie.Handler_CURIE",
    "citexplore": "manubot.cite.curie.Handler_CURIE",
    "cito": "manubot.cite.curie.Handler_CURIE",
    "civic.aid": "manubot.cite.curie.Handler_CURIE",
    "civic.did": "manubot.cite.curie.Handler_CURIE",
    "civic.eid": "manubot.cite.curie.Handler_CURIE",
    "civic.gid": "manubot.cite.curie.Handler_CURIE",
    "civic.sid": "manubot.cite.curie.Handler_CURIE",
    "civic.tid": "manubot.cite.curie.Handler_CURIE",
    "civic.vid": "manubot.cite.curie.Handler_CURIE",
    "cl": "manubot.cite.curie.Handler_CURIE",
    "clao": "manubot.cite.curie.Handler_CURIE",
    "classyfire": "manubot.cite.curie.Handler_CURIE",
    "cldb": "manubot.cite.curie.Handler_CURIE",
    "clingene": "manubot.cite.curie.Handler_CURIE",
    "clinicaltrials": "manubot.cite.curie.Handler_CURIE",
    "clinvar": "manubot.cite.curie.Handler_CURIE",
    "clinvar.record": "manubot.cite.curie.Handler_CURIE",
    "clinvar.submission": "manubot.cite.curie.Handler_CURIE",
    "clinvar.submitter": "manubot.cite.curie.Handler_CURIE",
    "clinvar.variant": "manubot.cite.curie.Handler_CURIE",
    "clinvar.variation": "manubot.cite.curie.Handler_CURIE",
    "clo": "manubot.cite.curie.Handler_CURIE",
    "cls": "manubot.cite.curie.Handler_CURIE",
    "clyh": "manubot.cite.curie.Handler_CURIE",
    "cmecs": "manubot.cite.curie.Handler_CURIE",
    "cmf": "manubot.cite.curie.Handler_CURIE",
    "cmo": "manubot.cite.curie.Handler_CURIE",
    "cmpo": "manubot.cite.curie.Handler_CURIE",
    "co_320": "manubot.cite.curie.Handler_CURIE",
    "co_321": "manubot.cite.curie.Handler_CURIE",
    "co_322": "manubot.cite.curie.Handler_CURIE",
    "co_323": "manubot.cite.curie.Handler_CURIE",
    "co_324": "manubot.cite.curie.Handler_CURIE",
    "co_325": "manubot.cite.curie.Handler_CURIE",
    "co_326": "manubot.cite.curie.Handler_CURIE",
    "co_327": "manubot.cite.curie.Handler_CURIE",
    "co_330": "manubot.cite.curie.Handler_CURIE",
    "co_331": "manubot.cite.curie.Handler_CURIE",
    "co_333": "manubot.cite.curie.Handler_CURIE",
    "co_334": "manubot.cite.curie.Handler_CURIE",
    "co_335": "manubot.cite.curie.Handler_CURIE",
    "co_336": "manubot.cite.curie.Handler_CURIE",
    "co_337": "manubot.cite.curie.Handler_CURIE",
    "co_338": "manubot.cite.curie.Handler_CURIE",
    "co_339": "manubot.cite.curie.Handler_CURIE",
    "co_340": "manubot.cite.curie.Handler_CURIE",
    "co_341": "manubot.cite.curie.Handler_CURIE",
    "co_343": "manubot.cite.curie.Handler_CURIE",
    "co_345": "manubot.cite.curie.Handler_CURIE",
    "co_346": "manubot.cite.curie.Handler_CURIE",
    "co_347": "manubot.cite.curie.Handler_CURIE",
    "co_348": "manubot.cite.curie.Handler_CURIE",
    "co_350": "manubot.cite.curie.Handler_CURIE",
    "co_356": "manubot.cite.curie.Handler_CURIE",
    "co_357": "manubot.cite.curie.Handler_CURIE",
    "co_358": "manubot.cite.curie.Handler_CURIE",
    "co_359": "manubot.cite.curie.Handler_CURIE",
    "co_360": "manubot.cite.curie.Handler_CURIE",
    "co_365": "manubot.cite.curie.Handler_CURIE",
    "co_366": "manubot.cite.curie.Handler_CURIE",
    "co_367": "manubot.cite.curie.Handler_CURIE",
    "co_370": "manubot.cite.curie.Handler_CURIE",
    "cob": "manubot.cite.curie.Handler_CURIE",
    "coconut": "manubot.cite.curie.Handler_CURIE",
    "cog": "manubot.cite.curie.Handler_CURIE",
    "cog.category": "manubot.cite.curie.Handler_CURIE",
    "cog.pathway": "manubot.cite.curie.Handler_CURIE",
    "cog_cluster": "manubot.cite.curie.Handler_CURIE",
    "col.taiwan": "manubot.cite.curie.Handler_CURIE",
    "colao": "manubot.cite.curie.Handler_CURIE",
    "collagenmutdb": "manubot.cite.curie.Handler_CURIE",
    "colonatlas": "manubot.cite.curie.Handler_CURIE",
    "combine.specifications": "manubot.cite.curie.Handler_CURIE",
    "come": "manubot.cite.curie.Handler_CURIE",
    "commoncoreontology": "manubot.cite.curie.Handler_CURIE",
    "complexportal": "manubot.cite.curie.Handler_CURIE",
    "comptox": "manubot.cite.curie.Handler_CURIE",
    "compulyeast": "manubot.cite.curie.Handler_CURIE",
    "confident.event": "manubot.cite.curie.Handler_CURIE",
    "confident.series": "manubot.cite.curie.Handler_CURIE",
    "conoserver": "manubot.cite.curie.Handler_CURIE",
    "conso": "manubot.cite.curie.Handler_CURIE",
    "cordis.article": "manubot.cite.curie.Handler_CURIE",
    "cordis.project": "manubot.cite.curie.Handler_CURIE",
    "coriell": "manubot.cite.curie.Handler_CURIE",
    "corrdb": "manubot.cite.curie.Handler_CURIE",
    "corum": "manubot.cite.curie.Handler_CURIE",
    "cosmic": "manubot.cite.curie.Handler_CURIE",
    "cosmic.cell": "manubot.cite.curie.Handler_CURIE",
    "covid19": "manubot.cite.curie.Handler_CURIE",
    "covoc": "manubot.cite.curie.Handler_CURIE",
    "cpc": "manubot.cite.curie.Handler_CURIE",
    "cpga": "manubot.cite.curie.Handler_CURIE",
    "cpt": "manubot.cite.curie.Handler_CURIE",
    "crisp": "manubot.cite.curie.Handler_CURIE",
    "crisprdb": "manubot.cite.curie.Handler_CURIE",
    "cro": "manubot.cite.curie.Handler_CURIE",
    "crop2ml": "manubot.cite.curie.Handler_CURIE",
    "cryoem": "manubot.cite.curie.Handler_CURIE",
    "cryptodb": "manubot.cite.curie.Handler_CURIE",
    "csa": "manubot.cite.curie.Handler_CURIE",
    "csd": "manubot.cite.curie.Handler_CURIE",
    "csp": "manubot.cite.curie.Handler_CURIE",
    "csp2005": "manubot.cite.curie.Handler_CURIE",
    "cst": "manubot.cite.curie.Handler_CURIE",
    "cst.ab": "manubot.cite.curie.Handler_CURIE",
    "ctd.chemical": "manubot.cite.curie.Handler_CURIE",
    "ctd.disease": "manubot.cite.curie.Handler_CURIE",
    "ctd.gene": "manubot.cite.curie.Handler_CURIE",
    "cteno": "manubot.cite.curie.Handler_CURIE",
    "cto": "manubot.cite.curie.Handler_CURIE",
    "ctx": "manubot.cite.curie.Handler_CURIE",
    "cubedb": "manubot.cite.curie.Handler_CURIE",
    "cutg": "manubot.cite.curie.Handler_CURIE",
    "cvcl": "manubot.cite.curie.Handler_CURIE",
    "cvdo": "manubot.cite.curie.Handler_CURIE",
    "d1id": "manubot.cite.curie.Handler_CURIE",
    "dailymed": "manubot.cite.curie.Handler_CURIE",
    "dandi": "manubot.cite.curie.Handler_CURIE",
    "darc": "manubot.cite.curie.Handler_CURIE",
    "dashr": "manubot.cite.curie.Handler_CURIE",
    "dashr.expression": "manubot.cite.curie.Handler_CURIE",
    "datacite": "manubot.cite.curie.Handler_CURIE",
    "datanator.gene": "manubot.cite.curie.Handler_CURIE",
    "datanator.metabolite": "manubot.cite.curie.Handler_CURIE",
    "datanator.reaction": "manubot.cite.curie.Handler_CURIE",
    "datf": "manubot.cite.curie.Handler_CURIE",
    "dbd": "manubot.cite.curie.Handler_CURIE",
    "dbest": "manubot.cite.curie.Handler_CURIE",
    "dbg2introns": "manubot.cite.curie.Handler_CURIE",
    "dbgap": "manubot.cite.curie.Handler_CURIE",
    "dbo": "manubot.cite.curie.Handler_CURIE",
    "dbprobe": "manubot.cite.curie.Handler_CURIE",
    "dbsnp": "manubot.cite.curie.Handler_CURIE",
    "dbvar.studies": "manubot.cite.curie.Handler_CURIE",
    "dbvar.study": "manubot.cite.curie.Handler_CURIE",
    "dbvar.variant": "manubot.cite.curie.Handler_CURIE",
    "dbvar.variants": "manubot.cite.curie.Handler_CURIE",
    "dc": "manubot.cite.curie.Handler_CURIE",
    "dc.terms": "manubot.cite.curie.Handler_CURIE",
    "dc11": "manubot.cite.curie.Handler_CURIE",
    "dc_cl": "manubot.cite.curie.Handler_CURIE",
    "dcat": "manubot.cite.curie.Handler_CURIE",
    "dct": "manubot.cite.curie.Handler_CURIE",
    "dcterms": "manubot.cite.curie.Handler_CURIE",
    "dctypes": "manubot.cite.curie.Handler_CURIE",
    "ddanat": "manubot.cite.curie.Handler_CURIE",
    "ddinter.drug": "manubot.cite.curie.Handler_CURIE",
    "ddinter.interaction": "manubot.cite.curie.Handler_CURIE",
    "ddpheno": "manubot.cite.curie.Handler_CURIE",
    "debio": "manubot.cite.curie.Handler_CURIE",
    "decipher": "manubot.cite.curie.Handler_CURIE",
    "degradome": "manubot.cite.curie.Handler_CURIE",
    "deo": "manubot.cite.curie.Handler_CURIE",
    "depmap": "manubot.cite.curie.Handler_CURIE",
    "depod": "manubot.cite.curie.Handler_CURIE",
    "dermo": "manubot.cite.curie.Handler_CURIE",
    "dev.ga4ghdos": "manubot.cite.curie.Handler_CURIE",
    "dg.4503": "manubot.cite.curie.Handler_CURIE",
    "dg.4dfc": "manubot.cite.curie.Handler_CURIE",
    "dg.6vts": "manubot.cite.curie.Handler_CURIE",
    "dg.anv0": "manubot.cite.curie.Handler_CURIE",
    "dg.f82a1a": "manubot.cite.curie.Handler_CURIE",
    "dg5b0d": "manubot.cite.curie.Handler_CURIE",
    "dgrc": "manubot.cite.curie.Handler_CURIE",
    "dhba": "manubot.cite.curie.Handler_CURIE",
    "di": "manubot.cite.curie.Handler_CURIE",
    "dicom": "manubot.cite.curie.Handler_CURIE",
    "dictybase": "manubot.cite.curie.Handler_CURIE",
    "dictybase.est": "manubot.cite.curie.Handler_CURIE",
    "dictybase.gene": "manubot.cite.curie.Handler_CURIE",
    "did": "manubot.cite.curie.Handler_CURIE",
    "dideo": "manubot.cite.curie.Handler_CURIE",
    "dinto": "manubot.cite.curie.Handler_CURIE",
    "dip": "manubot.cite.curie.Handler_CURIE",
    "discoverx": "manubot.cite.curie.Handler_CURIE",
    "disdriv": "manubot.cite.curie.Handler_CURIE",
    "diseaseclass": "manubot.cite.curie.Handler_CURIE",
    "diseasesdb": "manubot.cite.curie.Handler_CURIE",
    "disprot": "manubot.cite.curie.Handler_CURIE",
    "disprot.region": "manubot.cite.curie.Handler_CURIE",
    "dlxb": "manubot.cite.curie.Handler_CURIE",
    "dlxc": "manubot.cite.curie.Handler_CURIE",
    "dmba": "manubot.cite.curie.Handler_CURIE",
    "do": "manubot.cite.curie.Handler_CURIE",
    "doap": "manubot.cite.curie.Handler_CURIE",
    "doco": "manubot.cite.curie.Handler_CURIE",
    "doi": "manubot.cite.doi.Handler_DOI",
    "doid": "manubot.cite.curie.Handler_CURIE",
    "dommino": "manubot.cite.curie.Handler_CURIE",
    "door": "manubot.cite.curie.Handler_CURIE",
    "doqcs.model": "manubot.cite.curie.Handler_CURIE",
    "doqcs.pathway": "manubot.cite.curie.Handler_CURIE",
    "dpo": "manubot.cite.curie.Handler_CURIE",
    "dpv": "manubot.cite.curie.Handler_CURIE",
    "dragondb.allele": "manubot.cite.curie.Handler_CURIE",
    "dragondb.dna": "manubot.cite.curie.Handler_CURIE",
    "dragondb.locus": "manubot.cite.curie.Handler_CURIE",
    "dragondb.protein": "manubot.cite.curie.Handler_CURIE",
    "dron": "manubot.cite.curie.Handler_CURIE",
    "drsc": "manubot.cite.curie.Handler_CURIE",
    "drug_central": "manubot.cite.curie.Handler_CURIE",
    "drugbank": "manubot.cite.curie.Handler_CURIE",
    "drugbank.category": "manubot.cite.curie.Handler_CURIE",
    "drugbank.salt": "manubot.cite.curie.Handler_CURIE",
    "drugbank.target": "manubot.cite.curie.Handler_CURIE",
    "drugbank_id": "manubot.cite.curie.Handler_CURIE",
    "drugbankv4.target": "manubot.cite.curie.Handler_CURIE",
    "drugcentral": "manubot.cite.curie.Handler_CURIE",
    "dsmz": "manubot.cite.curie.Handler_CURIE",
    "dso": "manubot.cite.curie.Handler_CURIE",
    "dsstox_cid": "manubot.cite.curie.Handler_CURIE",
    "dsstox_generic_sid": "manubot.cite.curie.Handler_CURIE",
    "dto": "manubot.cite.curie.Handler_CURIE",
    "duo": "manubot.cite.curie.Handler_CURIE",
    "eaglei": "manubot.cite.curie.Handler_CURIE",
    "easychair.cfp": "manubot.cite.curie.Handler_CURIE",
    "easychair.topic": "manubot.cite.curie.Handler_CURIE",
    "ebisc": "manubot.cite.curie.Handler_CURIE",
    "ec": "manubot.cite.curie.Handler_CURIE",
    "ec-code": "manubot.cite.curie.Handler_CURIE",
    "ec_code": "manubot.cite.curie.Handler_CURIE",
    "ecacc": "manubot.cite.curie.Handler_CURIE",
    "ecao": "manubot.cite.curie.Handler_CURIE",
    "eccode": "manubot.cite.curie.Handler_CURIE",
    "ecg": "manubot.cite.curie.Handler_CURIE",
    "ecgontology": "manubot.cite.curie.Handler_CURIE",
    "echobase": "manubot.cite.curie.Handler_CURIE",
    "ecmdb": "manubot.cite.curie.Handler_CURIE",
    "eco": "manubot.cite.curie.Handler_CURIE",
    "ecocore": "manubot.cite.curie.Handler_CURIE",
    "ecocyc": "manubot.cite.curie.Handler_CURIE",
    "ecogene": "manubot.cite.curie.Handler_CURIE",
    "ecoliwiki": "manubot.cite.curie.Handler_CURIE",
    "ecto": "manubot.cite.curie.Handler_CURIE",
    "ecyano.entity": "manubot.cite.curie.Handler_CURIE",
    "ecyano.experiment": "manubot.cite.curie.Handler_CURIE",
    "ecyano.model": "manubot.cite.curie.Handler_CURIE",
    "ecyano.rule": "manubot.cite.curie.Handler_CURIE",
    "edam": "manubot.cite.curie.Handler_CURIE",
    "edam.data": "manubot.cite.curie.Handler_CURIE",
    "edam.format": "manubot.cite.curie.Handler_CURIE",
    "edam.operation": "manubot.cite.curie.Handler_CURIE",
    "edam.topic": "manubot.cite.curie.Handler_CURIE",
    "edda": "manubot.cite.curie.Handler_CURIE",
    "efo": "manubot.cite.curie.Handler_CURIE",
    "ega.dataset": "manubot.cite.curie.Handler_CURIE",
    "ega.study": "manubot.cite.curie.Handler_CURIE",
    "eggnog": "manubot.cite.curie.Handler_CURIE",
    "egid": "manubot.cite.curie.Handler_CURIE",
    "ehda": "manubot.cite.curie.Handler_CURIE",
    "ehdaa": "manubot.cite.curie.Handler_CURIE",
    "ehdaa2": "manubot.cite.curie.Handler_CURIE",
    "ehdaa2_retired": "manubot.cite.curie.Handler_CURIE",
    "elm": "manubot.cite.curie.Handler_CURIE",
    "emap": "manubot.cite.curie.Handler_CURIE",
    "emapa": "manubot.cite.curie.Handler_CURIE",
    "emapa_retired": "manubot.cite.curie.Handler_CURIE",
    "emdb": "manubot.cite.curie.Handler_CURIE",
    "emolecules": "manubot.cite.curie.Handler_CURIE",
    "empiar": "manubot.cite.curie.Handler_CURIE",
    "ena": "manubot.cite.curie.Handler_CURIE",
    "ena.embl": "manubot.cite.curie.Handler_CURIE",
    "encode": "manubot.cite.curie.Handler_CURIE",
    "enm": "manubot.cite.curie.Handler_CURIE",
    "ensembl": "manubot.cite.curie.Handler_CURIE",
    "ensembl.bacteria": "manubot.cite.curie.Handler_CURIE",
    "ensembl.fungi": "manubot.cite.curie.Handler_CURIE",
    "ensembl.metazoa": "manubot.cite.curie.Handler_CURIE",
    "ensembl.plant": "manubot.cite.curie.Handler_CURIE",
    "ensembl.protist": "manubot.cite.curie.Handler_CURIE",
    "ensemblglossary": "manubot.cite.curie.Handler_CURIE",
    "entrez": "manubot.cite.curie.Handler_CURIE",
    "entrezgene": "manubot.cite.curie.Handler_CURIE",
    "envipath": "manubot.cite.curie.Handler_CURIE",
    "envo": "manubot.cite.curie.Handler_CURIE",
    "enzo": "manubot.cite.curie.Handler_CURIE",
    "eo": "manubot.cite.curie.Handler_CURIE",
    "eol": "manubot.cite.curie.Handler_CURIE",
    "eolife": "manubot.cite.curie.Handler_CURIE",
    "epd": "manubot.cite.curie.Handler_CURIE",
    "epio": "manubot.cite.curie.Handler_CURIE",
    "epo": "manubot.cite.curie.Handler_CURIE",
    "epso": "manubot.cite.curie.Handler_CURIE",
    "erm": "manubot.cite.curie.Handler_CURIE",
    "ero": "manubot.cite.curie.Handler_CURIE",
    "eropmoscow": "manubot.cite.curie.Handler_CURIE",
    "erv": "manubot.cite.curie.Handler_CURIE",
    "esldb": "manubot.cite.curie.Handler_CURIE",
    "estdab": "manubot.cite.curie.Handler_CURIE",
    "eu89h": "manubot.cite.curie.Handler_CURIE",
    "euclinicaltrials": "manubot.cite.curie.Handler_CURIE",
    "eugenes": "manubot.cite.curie.Handler_CURIE",
    "eupath": "manubot.cite.curie.Handler_CURIE",
    "ev": "manubot.cite.curie.Handler_CURIE",
    "exac.gene": "manubot.cite.curie.Handler_CURIE",
    "exac.transcript": "manubot.cite.curie.Handler_CURIE",
    "exac.variant": "manubot.cite.curie.Handler_CURIE",
    "exo": "manubot.cite.curie.Handler_CURIE",
    "fabio": "manubot.cite.curie.Handler_CURIE",
    "facebase": "manubot.cite.curie.Handler_CURIE",
    "fairsharing": "manubot.cite.curie.Handler_CURIE",
    "faldo": "manubot.cite.curie.Handler_CURIE",
    "famplex": "manubot.cite.curie.Handler_CURIE",
    "fao": "manubot.cite.curie.Handler_CURIE",
    "fb": "manubot.cite.curie.Handler_CURIE",
    "fbbi": "manubot.cite.curie.Handler_CURIE",
    "fbbt": "manubot.cite.curie.Handler_CURIE",
    "fbbt_root": "manubot.cite.curie.Handler_CURIE",
    "fbcv": "manubot.cite.curie.Handler_CURIE",
    "fbdv": "manubot.cite.curie.Handler_CURIE",
    "fbol": "manubot.cite.curie.Handler_CURIE",
    "fbrf": "manubot.cite.curie.Handler_CURIE",
    "fbsp": "manubot.cite.curie.Handler_CURIE",
    "fbtc": "manubot.cite.curie.Handler_CURIE",
    "fcb": "manubot.cite.curie.Handler_CURIE",
    "fcsfree": "manubot.cite.curie.Handler_CURIE",
    "fhir.implementation": "manubot.cite.curie.Handler_CURIE",
    "fideo": "manubot.cite.curie.Handler_CURIE",
    "fishbase": "manubot.cite.curie.Handler_CURIE",
    "fishbase.species": "manubot.cite.curie.Handler_CURIE",
    "fix": "manubot.cite.curie.Handler_CURIE",
    "flopo": "manubot.cite.curie.Handler_CURIE",
    "flowrepository": "manubot.cite.curie.Handler_CURIE",
    "flu": "manubot.cite.curie.Handler_CURIE",
    "flybase": "manubot.cite.curie.Handler_CURIE",
    "flybrain.ndb": "manubot.cite.curie.Handler_CURIE",
    "flymine.chromosome": "manubot.cite.curie.Handler_CURIE",
    "fma": "manubot.cite.curie.Handler_CURIE",
    "fma_retired": "manubot.cite.curie.Handler_CURIE",
    "fmaid": "manubot.cite.curie.Handler_CURIE",
    "foaf": "manubot.cite.curie.Handler_CURIE",
    "fobi": "manubot.cite.curie.Handler_CURIE",
    "foodb": "manubot.cite.curie.Handler_CURIE",
    "foodb.compound": "manubot.cite.curie.Handler_CURIE",
    "foodb.food": "manubot.cite.curie.Handler_CURIE",
    "foodex2": "manubot.cite.curie.Handler_CURIE",
    "foodon": "manubot.cite.curie.Handler_CURIE",
    "fossilworks.journal": "manubot.cite.curie.Handler_CURIE",
    "fossilworks.taxon": "manubot.cite.curie.Handler_CURIE",
    "fovt": "manubot.cite.curie.Handler_CURIE",
    "fplx": "manubot.cite.curie.Handler_CURIE",
    "frapo": "manubot.cite.curie.Handler_CURIE",
    "frbr": "manubot.cite.curie.Handler_CURIE",
    "fsnp": "manubot.cite.curie.Handler_CURIE",
    "ftt": "manubot.cite.curie.Handler_CURIE",
    "funcbase.fly": "manubot.cite.curie.Handler_CURIE",
    "funcbase.human": "manubot.cite.curie.Handler_CURIE",
    "funcbase.mouse": "manubot.cite.curie.Handler_CURIE",
    "funcbase.yeast": "manubot.cite.curie.Handler_CURIE",
    "funderregistry": "manubot.cite.curie.Handler_CURIE",
    "fungidb": "manubot.cite.curie.Handler_CURIE",
    "fungorum": "manubot.cite.curie.Handler_CURIE",
    "fypo": "manubot.cite.curie.Handler_CURIE",
    "ga4ghdos": "manubot.cite.curie.Handler_CURIE",
    "gabi": "manubot.cite.curie.Handler_CURIE",
    "galen": "manubot.cite.curie.Handler_CURIE",
    "gard": "manubot.cite.curie.Handler_CURIE",
    "gateway": "manubot.cite.curie.Handler_CURIE",
    "gaz": "manubot.cite.curie.Handler_CURIE",
    "gbif": "manubot.cite.curie.Handler_CURIE",
    "gc": "manubot.cite.curie.Handler_CURIE",
    "gc_id": "manubot.cite.curie.Handler_CURIE",
    "gcst": "manubot.cite.curie.Handler_CURIE",
    "gdc": "manubot.cite.curie.Handler_CURIE",
    "gdsc": "manubot.cite.curie.Handler_CURIE",
    "gecko": "manubot.cite.curie.Handler_CURIE",
    "gemet": "manubot.cite.curie.Handler_CURIE",
    "genatlas": "manubot.cite.curie.Handler_CURIE",
    "genbank": "manubot.cite.curie.Handler_CURIE",
    "gendis": "manubot.cite.curie.Handler_CURIE",
    "genecards": "manubot.cite.curie.Handler_CURIE",
    "genecards.geneloc": "manubot.cite.curie.Handler_CURIE",
    "genedb": "manubot.cite.curie.Handler_CURIE",
    "genefarm": "manubot.cite.curie.Handler_CURIE",
    "genepio": "manubot.cite.curie.Handler_CURIE",
    "genetree": "manubot.cite.curie.Handler_CURIE",
    "genewiki": "manubot.cite.curie.Handler_CURIE",
    "geno": "manubot.cite.curie.Handler_CURIE",
    "genpept": "manubot.cite.curie.Handler_CURIE",
    "genprop": "manubot.cite.curie.Handler_CURIE",
    "geo": "manubot.cite.curie.Handler_CURIE",
    "geogeo": "manubot.cite.curie.Handler_CURIE",
    "geomames": "manubot.cite.curie.Handler_CURIE",
    "geonamaes": "manubot.cite.curie.Handler_CURIE",
    "geonames": "manubot.cite.curie.Handler_CURIE",
    "geonames.feature": "manubot.cite.curie.Handler_CURIE",
    "gfam": "manubot.cite.curie.Handler_CURIE",
    "gfo": "manubot.cite.curie.Handler_CURIE",
    "ghr": "manubot.cite.curie.Handler_CURIE",
    "giardiadb": "manubot.cite.curie.Handler_CURIE",
    "github": "manubot.cite.curie.Handler_CURIE",
    "github.issue": "manubot.cite.curie.Handler_CURIE",
    "github.pull": "manubot.cite.curie.Handler_CURIE",
    "gitlab": "manubot.cite.curie.Handler_CURIE",
    "glida.gpcr": "manubot.cite.curie.Handler_CURIE",
    "glida.ligand": "manubot.cite.curie.Handler_CURIE",
    "glycoepitope": "manubot.cite.curie.Handler_CURIE",
    "glycomapsdb": "manubot.cite.curie.Handler_CURIE",
    "glycomedb": "manubot.cite.curie.Handler_CURIE",
    "glyconavi": "manubot.cite.curie.Handler_CURIE",
    "glycopost": "manubot.cite.curie.Handler_CURIE",
    "glycosciences.db": "manubot.cite.curie.Handler_CURIE",
    "glycosciencesdb": "manubot.cite.curie.Handler_CURIE",
    "glygen": "manubot.cite.curie.Handler_CURIE",
    "glytoucan": "manubot.cite.curie.Handler_CURIE",
    "gmd": "manubot.cite.curie.Handler_CURIE",
    "gmd.analyte": "manubot.cite.curie.Handler_CURIE",
    "gmd.gcms": "manubot.cite.curie.Handler_CURIE",
    "gmd.profile": "manubot.cite.curie.Handler_CURIE",
    "gmd.ref": "manubot.cite.curie.Handler_CURIE",
    "gno": "manubot.cite.curie.Handler_CURIE",
    "gnome": "manubot.cite.curie.Handler_CURIE",
    "gnpis": "manubot.cite.curie.Handler_CURIE",
    "go": "manubot.cite.curie.Handler_CURIE",
    "go.chebi": "manubot.cite.curie.Handler_CURIE",
    "go.chemical": "manubot.cite.curie.Handler_CURIE",
    "go.chemicals": "manubot.cite.curie.Handler_CURIE",
    "go.model": "manubot.cite.curie.Handler_CURIE",
    "go.ref": "manubot.cite.curie.Handler_CURIE",
    "go.resource": "manubot.cite.curie.Handler_CURIE",
    "goa": "manubot.cite.curie.Handler_CURIE",
    "gobp": "manubot.cite.curie.Handler_CURIE",
    "gobpid": "manubot.cite.curie.Handler_CURIE",
    "gocc": "manubot.cite.curie.Handler_CURIE",
    "goccid": "manubot.cite.curie.Handler_CURIE",
    "goche": "manubot.cite.curie.Handler_CURIE",
    "gold": "manubot.cite.curie.Handler_CURIE",
    "gold.genome": "manubot.cite.curie.Handler_CURIE",
    "gold.meta": "manubot.cite.curie.Handler_CURIE",
    "goldbook": "manubot.cite.curie.Handler_CURIE",
    "gomf": "manubot.cite.curie.Handler_CURIE",
    "gomfid": "manubot.cite.curie.Handler_CURIE",
    "google.book": "manubot.cite.curie.Handler_CURIE",
    "google.patent": "manubot.cite.curie.Handler_CURIE",
    "gpcrdb": "manubot.cite.curie.Handler_CURIE",
    "gpmdb": "manubot.cite.curie.Handler_CURIE",
    "gr_gene": "manubot.cite.curie.Handler_CURIE",
    "gr_protein": "manubot.cite.curie.Handler_CURIE",
    "gr_qtl": "manubot.cite.curie.Handler_CURIE",
    "graingenes.reference": "manubot.cite.curie.Handler_CURIE",
    "graingenes.symbol": "manubot.cite.curie.Handler_CURIE",
    "gramene.gene": "manubot.cite.curie.Handler_CURIE",
    "gramene.growthstage": "manubot.cite.curie.Handler_CURIE",
    "gramene.protein": "manubot.cite.curie.Handler_CURIE",
    "gramene.qtl": "manubot.cite.curie.Handler_CURIE",
    "gramene.ref": "manubot.cite.curie.Handler_CURIE",
    "gramene.reference": "manubot.cite.curie.Handler_CURIE",
    "gramene.taxonomy": "manubot.cite.curie.Handler_CURIE",
    "grassbase": "manubot.cite.curie.Handler_CURIE",
    "greengenes": "manubot.cite.curie.Handler_CURIE",
    "grid": "manubot.cite.curie.Handler_CURIE",
    "grin": "manubot.cite.curie.Handler_CURIE",
    "grin.taxonomy": "manubot.cite.curie.Handler_CURIE",
    "gro": "manubot.cite.curie.Handler_CURIE",
    "gro-cpga": "manubot.cite.curie.Handler_CURIE",
    "grsdb": "manubot.cite.curie.Handler_CURIE",
    "gsfa": "manubot.cite.curie.Handler_CURIE",
    "gsso": "manubot.cite.curie.Handler_CURIE",
    "gtex": "manubot.cite.curie.Handler_CURIE",
    "gtr": "manubot.cite.curie.Handler_CURIE",
    "gudmap": "manubot.cite.curie.Handler_CURIE",
    "gwascentral.marker": "manubot.cite.curie.Handler_CURIE",
    "gwascentral.phenotype": "manubot.cite.curie.Handler_CURIE",
    "gwascentral.study": "manubot.cite.curie.Handler_CURIE",
    "gxa.expt": "manubot.cite.curie.Handler_CURIE",
    "gxa.gene": "manubot.cite.curie.Handler_CURIE",
    "habronattus": "manubot.cite.curie.Handler_CURIE",
    "hagr.genage": "manubot.cite.curie.Handler_CURIE",
    "hagr.gendr": "manubot.cite.curie.Handler_CURIE",
    "hamap": "manubot.cite.curie.Handler_CURIE",
    "hancestro": "manubot.cite.curie.Handler_CURIE",
    "hao": "manubot.cite.curie.Handler_CURIE",
    "hathitrust": "manubot.cite.curie.Handler_CURIE",
    "hba": "manubot.cite.curie.Handler_CURIE",
    "hbvar": "manubot.cite.curie.Handler_CURIE",
    "hc.npn": "manubot.cite.curie.Handler_CURIE",
    "hcpcs": "manubot.cite.curie.Handler_CURIE",
    "hcvdb": "manubot.cite.curie.Handler_CURIE",
    "hdaa2": "manubot.cite.curie.Handler_CURIE",
    "hdr": "manubot.cite.curie.Handler_CURIE",
    "hgmd": "manubot.cite.curie.Handler_CURIE",
    "hgnc": "manubot.cite.curie.Handler_CURIE",
    "hgnc.family": "manubot.cite.curie.Handler_CURIE",
    "hgnc.genefamily": "manubot.cite.curie.Handler_CURIE",
    "hgnc.genegroup": "manubot.cite.curie.Handler_CURIE",
    "hgnc.symbol": "manubot.cite.curie.Handler_CURIE",
    "hgnc_group": "manubot.cite.curie.Handler_CURIE",
    "hinv.locus": "manubot.cite.curie.Handler_CURIE",
    "hinv.protein": "manubot.cite.curie.Handler_CURIE",
    "hinv.transcript": "manubot.cite.curie.Handler_CURIE",
    "hipsci": "manubot.cite.curie.Handler_CURIE",
    "hivreagentprogram": "manubot.cite.curie.Handler_CURIE",
    "hl7.v2codesystem": "manubot.cite.curie.Handler_CURIE",
    "hl7.v3codesystem": "manubot.cite.curie.Handler_CURIE",
    "hmdb": "manubot.cite.curie.Handler_CURIE",
    "hms-lincs": "manubot.cite.curie.Handler_CURIE",
    "hms.lincs.compound": "manubot.cite.curie.Handler_CURIE",
    "hmsl_id": "manubot.cite.curie.Handler_CURIE",
    "hog": "manubot.cite.curie.Handler_CURIE",
    "hogenom": "manubot.cite.curie.Handler_CURIE",
    "hom": "manubot.cite.curie.Handler_CURIE",
    "homd.seq": "manubot.cite.curie.Handler_CURIE",
    "homd.taxon": "manubot.cite.curie.Handler_CURIE",
    "homologene": "manubot.cite.curie.Handler_CURIE",
    "horizon_discovery": "manubot.cite.curie.Handler_CURIE",
    "hovergen": "manubot.cite.curie.Handler_CURIE",
    "hp": "manubot.cite.curie.Handler_CURIE",
    "hpa": "manubot.cite.curie.Handler_CURIE",
    "hpath": "manubot.cite.curie.Handler_CURIE",
    "hpm.peptide": "manubot.cite.curie.Handler_CURIE",
    "hpm.protein": "manubot.cite.curie.Handler_CURIE",
    "hpo": "manubot.cite.curie.Handler_CURIE",
    "hprd": "manubot.cite.curie.Handler_CURIE",
    "hpscreg": "manubot.cite.curie.Handler_CURIE",
    "hsapdv": "manubot.cite.curie.Handler_CURIE",
    "hsdb": "manubot.cite.curie.Handler_CURIE",
    "hso": "manubot.cite.curie.Handler_CURIE",
    "hssp": "manubot.cite.curie.Handler_CURIE",
    "htn": "manubot.cite.curie.Handler_CURIE",
    "http": "manubot.cite.url.Handler_URL",
    "https": "manubot.cite.url.Handler_URL",
    "huge": "manubot.cite.curie.Handler_CURIE",
    "iao": "manubot.cite.curie.Handler_CURIE",
    "ic9cm": "manubot.cite.curie.Handler_CURIE",
    "icd": "manubot.cite.curie.Handler_CURIE",
    "icd-10": "manubot.cite.curie.Handler_CURIE",
    "icd-11": "manubot.cite.curie.Handler_CURIE",
    "icd-o": "manubot.cite.curie.Handler_CURIE",
    "icd10": "manubot.cite.curie.Handler_CURIE",
    "icd10cm": "manubot.cite.curie.Handler_CURIE",
    "icd10pcs": "manubot.cite.curie.Handler_CURIE",
    "icd10who": "manubot.cite.curie.Handler_CURIE",
    "icd11": "manubot.cite.curie.Handler_CURIE",
    "icd9": "manubot.cite.curie.Handler_CURIE",
    "icd9_2005": "manubot.cite.curie.Handler_CURIE",
    "icd9cm": "manubot.cite.curie.Handler_CURIE",
    "icd9cm_2005": "manubot.cite.curie.Handler_CURIE",
    "icd9cm_2006": "manubot.cite.curie.Handler_CURIE",
    "icdc": "manubot.cite.curie.Handler_CURIE",
    "icdcm_2005": "manubot.cite.curie.Handler_CURIE",
    "icdo": "manubot.cite.curie.Handler_CURIE",
    "iceberg.cime": "manubot.cite.curie.Handler_CURIE",
    "iceberg.element": "manubot.cite.curie.Handler_CURIE",
    "iceberg.family": "manubot.cite.curie.Handler_CURIE",
    "iceberg.ice": "manubot.cite.curie.Handler_CURIE",
    "iceberg.ime": "manubot.cite.curie.Handler_CURIE",
    "iceo": "manubot.cite.curie.Handler_CURIE",
    "icepo": "manubot.cite.curie.Handler_CURIE",
    "icf": "manubot.cite.curie.Handler_CURIE",
    "iclc": "manubot.cite.curie.Handler_CURIE",
    "ico": "manubot.cite.curie.Handler_CURIE",
    "ideal": "manubot.cite.curie.Handler_CURIE",
    "identifiers.namespace": "manubot.cite.curie.Handler_CURIE",
    "ido": "manubot.cite.curie.Handler_CURIE",
    "idocovid19": "manubot.cite.curie.Handler_CURIE",
    "idoden": "manubot.cite.curie.Handler_CURIE",
    "idomal": "manubot.cite.curie.Handler_CURIE",
    "idoo": "manubot.cite.curie.Handler_CURIE",
    "idot": "manubot.cite.curie.Handler_CURIE",
    "idpo": "manubot.cite.curie.Handler_CURIE",
    "idr": "manubot.cite.curie.Handler_CURIE",
    "iedb": "manubot.cite.curie.Handler_CURIE",
    "iev": "manubot.cite.curie.Handler_CURIE",
    "igrhcellid": "manubot.cite.curie.Handler_CURIE",
    "igsn": "manubot.cite.curie.Handler_CURIE",
    "igsr": "manubot.cite.curie.Handler_CURIE",
    "ilx": "manubot.cite.curie.Handler_CURIE",
    "imanis": "manubot.cite.curie.Handler_CURIE",
    "imex": "manubot.cite.curie.Handler_CURIE",
    "img.gene": "manubot.cite.curie.Handler_CURIE",
    "img.taxon": "manubot.cite.curie.Handler_CURIE",
    "imgt.hla": "manubot.cite.curie.Handler_CURIE",
    "imgt.ligm": "manubot.cite.curie.Handler_CURIE",
    "imotdb": "manubot.cite.curie.Handler_CURIE",
    "imr": "manubot.cite.curie.Handler_CURIE",
    "inaturalist.observation": "manubot.cite.curie.Handler_CURIE",
    "inaturalist.place": "manubot.cite.curie.Handler_CURIE",
    "inaturalist.taxon": "manubot.cite.curie.Handler_CURIE",
    "inaturalist.user": "manubot.cite.curie.Handler_CURIE",
    "inchi": "manubot.cite.curie.Handler_CURIE",
    "inchikey": "manubot.cite.curie.Handler_CURIE",
    "inn": "manubot.cite.curie.Handler_CURIE",
    "inn_id": "manubot.cite.curie.Handler_CURIE",
    "innatedb": "manubot.cite.curie.Handler_CURIE",
    "ino": "manubot.cite.curie.Handler_CURIE",
    "insdc": "manubot.cite.curie.Handler_CURIE",
    "insdc.cds": "manubot.cite.curie.Handler_CURIE",
    "insdc.gca": "manubot.cite.curie.Handler_CURIE",
    "insdc.run": "manubot.cite.curie.Handler_CURIE",
    "insdc.sra": "manubot.cite.curie.Handler_CURIE",
    "intact": "manubot.cite.curie.Handler_CURIE",
    "intact.molecule": "manubot.cite.curie.Handler_CURIE",
    "intenz": "manubot.cite.curie.Handler_CURIE",
    "interfil": "manubot.cite.curie.Handler_CURIE",
    "interlex": "manubot.cite.curie.Handler_CURIE",
    "interpro": "manubot.cite.curie.Handler_CURIE",
    "inxight": "manubot.cite.curie.Handler_CURIE",
    "inxight-drugs": "manubot.cite.curie.Handler_CURIE",
    "ip": "manubot.cite.curie.Handler_CURIE",
    "ipr": "manubot.cite.curie.Handler_CURIE",
    "ird.segment": "manubot.cite.curie.Handler_CURIE",
    "irefweb": "manubot.cite.curie.Handler_CURIE",
    "iresite": "manubot.cite.curie.Handler_CURIE",
    "irgsp": "manubot.cite.curie.Handler_CURIE",
    "iro": "manubot.cite.curie.Handler_CURIE",
    "isbn": "manubot.cite.isbn.Handler_ISBN",
    "isbn-10": "manubot.cite.curie.Handler_CURIE",
    "isbn-13": "manubot.cite.curie.Handler_CURIE",
    "isfinder": "manubot.cite.curie.Handler_CURIE",
    "isni": "manubot.cite.curie.Handler_CURIE",
    "issn": "manubot.cite.curie.Handler_CURIE",
    "itis": "manubot.cite.curie.Handler_CURIE",
    "ito": "manubot.cite.curie.Handler_CURIE",
    "iuphar.family": "manubot.cite.curie.Handler_CURIE",
    "iuphar.ligand": "manubot.cite.curie.Handler_CURIE",
    "iuphar.receptor": "manubot.cite.curie.Handler_CURIE",
    "iuphar_gpcr": "manubot.cite.curie.Handler_CURIE",
    "iuphar_ligand": "manubot.cite.curie.Handler_CURIE",
    "iuphar_ligand_id": "manubot.cite.curie.Handler_CURIE",
    "iupharfam": "manubot.cite.curie.Handler_CURIE",
    "iupharobj": "manubot.cite.curie.Handler_CURIE",
    "jax": "manubot.cite.curie.Handler_CURIE",
    "jaxmice": "manubot.cite.curie.Handler_CURIE",
    "jcggdb": "manubot.cite.curie.Handler_CURIE",
    "jcm": "manubot.cite.curie.Handler_CURIE",
    "jcrb": "manubot.cite.curie.Handler_CURIE",
    "jcsd": "manubot.cite.curie.Handler_CURIE",
    "jstor": "manubot.cite.curie.Handler_CURIE",
    "jws": "manubot.cite.curie.Handler_CURIE",
    "kaggle": "manubot.cite.curie.Handler_CURIE",
    "kclb": "manubot.cite.curie.Handler_CURIE",
    "kegg": "manubot.cite.curie.Handler_CURIE",
    "kegg-path": "manubot.cite.curie.Handler_CURIE",
    "kegg.compound": "manubot.cite.curie.Handler_CURIE",
    "kegg.disease": "manubot.cite.curie.Handler_CURIE",
    "kegg.drug": "manubot.cite.curie.Handler_CURIE",
    "kegg.edrug": "manubot.cite.curie.Handler_CURIE",
    "kegg.environ": "manubot.cite.curie.Handler_CURIE",
    "kegg.enzyme": "manubot.cite.curie.Handler_CURIE",
    "kegg.genes": "manubot.cite.curie.Handler_CURIE",
    "kegg.genome": "manubot.cite.curie.Handler_CURIE",
    "kegg.glycan": "manubot.cite.curie.Handler_CURIE",
    "kegg.ligand": "manubot.cite.curie.Handler_CURIE",
    "kegg.metagenome": "manubot.cite.curie.Handler_CURIE",
    "kegg.module": "manubot.cite.curie.Handler_CURIE",
    "kegg.orthology": "manubot.cite.curie.Handler_CURIE",
    "kegg.pathway": "manubot.cite.curie.Handler_CURIE",
    "kegg.reaction": "manubot.cite.curie.Handler_CURIE",
    "kegg_genome": "manubot.cite.curie.Handler_CURIE",
    "kegg_genomes": "manubot.cite.curie.Handler_CURIE",
    "kegg_pathway": "manubot.cite.curie.Handler_CURIE",
    "kegg_reaction": "manubot.cite.curie.Handler_CURIE",
    "kerafast": "manubot.cite.curie.Handler_CURIE",
    "kisao": "manubot.cite.curie.Handler_CURIE",
    "knapsack": "manubot.cite.curie.Handler_CURIE",
    "kyinno": "manubot.cite.curie.Handler_CURIE",
    "labo": "manubot.cite.curie.Handler_CURIE",
    "langual": "manubot.cite.curie.Handler_CURIE",
    "lbo": "manubot.cite.curie.Handler_CURIE",
    "lei": "manubot.cite.curie.Handler_CURIE",
    "lepao": "manubot.cite.curie.Handler_CURIE",
    "lgai.cede": "manubot.cite.curie.Handler_CURIE",
    "lgic": "manubot.cite.curie.Handler_CURIE",
    "licebase": "manubot.cite.curie.Handler_CURIE",
    "ligandbook": "manubot.cite.curie.Handler_CURIE",
    "ligandbox": "manubot.cite.curie.Handler_CURIE",
    "ligandexpo": "manubot.cite.curie.Handler_CURIE",
    "ligea": "manubot.cite.curie.Handler_CURIE",
    "limore": "manubot.cite.curie.Handler_CURIE",
    "lincs": "manubot.cite.curie.Handler_CURIE",
    "lincs.cell": "manubot.cite.curie.Handler_CURIE",
    "lincs.data": "manubot.cite.curie.Handler_CURIE",
    "lincs.protein": "manubot.cite.curie.Handler_CURIE",
    "lincs.smallmolecule": "manubot.cite.curie.Handler_CURIE",
    "lincs_ldp": "manubot.cite.curie.Handler_CURIE",
    "linguist": "manubot.cite.curie.Handler_CURIE",
    "linkml": "manubot.cite.curie.Handler_CURIE",
    "lipid_maps_class": "manubot.cite.curie.Handler_CURIE",
    "lipid_maps_instance": "manubot.cite.curie.Handler_CURIE",
    "lipidbank": "manubot.cite.curie.Handler_CURIE",
    "lipidmaps": "manubot.cite.curie.Handler_CURIE",
    "lipro": "manubot.cite.curie.Handler_CURIE",
    "lnc": "manubot.cite.curie.Handler_CURIE",
    "lncrnadb": "manubot.cite.curie.Handler_CURIE",
    "loggerhead": "manubot.cite.curie.Handler_CURIE",
    "loinc": "manubot.cite.curie.Handler_CURIE",
    "lonza": "manubot.cite.curie.Handler_CURIE",
    "loqate": "manubot.cite.curie.Handler_CURIE",
    "lotus": "manubot.cite.curie.Handler_CURIE",
    "lpt": "manubot.cite.curie.Handler_CURIE",
    "lrg": "manubot.cite.curie.Handler_CURIE",
    "lspci": "manubot.cite.curie.Handler_CURIE",
    "lter": "manubot.cite.curie.Handler_CURIE",
    "ma": "manubot.cite.curie.Handler_CURIE",
    "macie": "manubot.cite.curie.Handler_CURIE",
    "maizegdb": "manubot.cite.curie.Handler_CURIE",
    "maizegdb.locus": "manubot.cite.curie.Handler_CURIE",
    "mamo": "manubot.cite.curie.Handler_CURIE",
    "mampol": "manubot.cite.curie.Handler_CURIE",
    "mao": "manubot.cite.curie.Handler_CURIE",
    "massbank": "manubot.cite.curie.Handler_CURIE",
    "massive": "manubot.cite.curie.Handler_CURIE",
    "mat": "manubot.cite.curie.Handler_CURIE",
    "matrixdb": "manubot.cite.curie.Handler_CURIE",
    "matrixdb.association": "manubot.cite.curie.Handler_CURIE",
    "maxo": "manubot.cite.curie.Handler_CURIE",
    "mba": "manubot.cite.curie.Handler_CURIE",
    "mc": "manubot.cite.curie.Handler_CURIE",
    "mcc": "manubot.cite.curie.Handler_CURIE",
    "mco": "manubot.cite.curie.Handler_CURIE",
    "mdm": "manubot.cite.curie.Handler_CURIE",
    "meddra": "manubot.cite.curie.Handler_CURIE",
    "medgen": "manubot.cite.curie.Handler_CURIE",
    "medgen.gtr": "manubot.cite.curie.Handler_CURIE",
    "medline": "manubot.cite.curie.Handler_CURIE",
    "medlineplus": "manubot.cite.curie.Handler_CURIE",
    "medra": "manubot.cite.curie.Handler_CURIE",
    "merops.clan": "manubot.cite.curie.Handler_CURIE",
    "merops.entry": "manubot.cite.curie.Handler_CURIE",
    "merops.family": "manubot.cite.curie.Handler_CURIE",
    "merops.inhibitor": "manubot.cite.curie.Handler_CURIE",
    "mesh": "manubot.cite.curie.Handler_CURIE",
    "mesh.2012": "manubot.cite.curie.Handler_CURIE",
    "mesh.2013": "manubot.cite.curie.Handler_CURIE",
    "mesh_descriptor_ui": "manubot.cite.curie.Handler_CURIE",
    "mesh_supplemental_record_ui": "manubot.cite.curie.Handler_CURIE",
    "mesha": "manubot.cite.curie.Handler_CURIE",
    "meshc": "manubot.cite.curie.Handler_CURIE",
    "meshcs": "manubot.cite.curie.Handler_CURIE",
    "meshd": "manubot.cite.curie.Handler_CURIE",
    "meshpp": "manubot.cite.curie.Handler_CURIE",
    "metabolights": "manubot.cite.curie.Handler_CURIE",
    "metacyc": "manubot.cite.curie.Handler_CURIE",
    "metacyc.compound": "manubot.cite.curie.Handler_CURIE",
    "metacyc.reaction": "manubot.cite.curie.Handler_CURIE",
    "metanetx.chemical": "manubot.cite.curie.Handler_CURIE",
    "metanetx.compartment": "manubot.cite.curie.Handler_CURIE",
    "metanetx.reaction": "manubot.cite.curie.Handler_CURIE",
    "metatlas": "manubot.cite.curie.Handler_CURIE",
    "metatlas.metabolite": "manubot.cite.curie.Handler_CURIE",
    "metatlas.reaction": "manubot.cite.curie.Handler_CURIE",
    "metlin": "manubot.cite.curie.Handler_CURIE",
    "metnetdb": "manubot.cite.curie.Handler_CURIE",
    "mex": "manubot.cite.curie.Handler_CURIE",
    "mf": "manubot.cite.curie.Handler_CURIE",
    "mfmo": "manubot.cite.curie.Handler_CURIE",
    "mfo": "manubot.cite.curie.Handler_CURIE",
    "mfoem": "manubot.cite.curie.Handler_CURIE",
    "mfomd": "manubot.cite.curie.Handler_CURIE",
    "mgd": "manubot.cite.curie.Handler_CURIE",
    "mge": "manubot.cite.curie.Handler_CURIE",
    "mgi": "manubot.cite.curie.Handler_CURIE",
    "mgnify.analysis": "manubot.cite.curie.Handler_CURIE",
    "mgnify.proj": "manubot.cite.curie.Handler_CURIE",
    "mgnify.samp": "manubot.cite.curie.Handler_CURIE",
    "mi": "manubot.cite.curie.Handler_CURIE",
    "miapa": "manubot.cite.curie.Handler_CURIE",
    "micro": "manubot.cite.curie.Handler_CURIE",
    "microscope": "manubot.cite.curie.Handler_CURIE",
    "microsporidia": "manubot.cite.curie.Handler_CURIE",
    "millipore": "manubot.cite.curie.Handler_CURIE",
    "mim": "manubot.cite.curie.Handler_CURIE",
    "mim.ps": "manubot.cite.curie.Handler_CURIE",
    "mimodb": "manubot.cite.curie.Handler_CURIE",
    "mimps": "manubot.cite.curie.Handler_CURIE",
    "minid": "manubot.cite.curie.Handler_CURIE",
    "minid.test": "manubot.cite.curie.Handler_CURIE",
    "mint": "manubot.cite.curie.Handler_CURIE",
    "mipmod": "manubot.cite.curie.Handler_CURIE",
    "mir": "manubot.cite.curie.Handler_CURIE",
    "mirbase": "manubot.cite.curie.Handler_CURIE",
    "mirbase.family": "manubot.cite.curie.Handler_CURIE",
    "mirbase.mature": "manubot.cite.curie.Handler_CURIE",
    "mirbase_family": "manubot.cite.curie.Handler_CURIE",
    "mirbasem": "manubot.cite.curie.Handler_CURIE",
    "mirex": "manubot.cite.curie.Handler_CURIE",
    "miriam": "manubot.cite.curie.Handler_CURIE",
    "miriam.collection": "manubot.cite.curie.Handler_CURIE",
    "miriam.resource": "manubot.cite.curie.Handler_CURIE",
    "mirnao": "manubot.cite.curie.Handler_CURIE",
    "mirnest": "manubot.cite.curie.Handler_CURIE",
    "miro": "manubot.cite.curie.Handler_CURIE",
    "mirtarbase": "manubot.cite.curie.Handler_CURIE",
    "mlc": "manubot.cite.curie.Handler_CURIE",
    "mmdb": "manubot.cite.curie.Handler_CURIE",
    "mmmp.biomaps": "manubot.cite.curie.Handler_CURIE",
    "mmo": "manubot.cite.curie.Handler_CURIE",
    "mmp.cat": "manubot.cite.curie.Handler_CURIE",
    "mmp.db": "manubot.cite.curie.Handler_CURIE",
    "mmp.fun": "manubot.cite.curie.Handler_CURIE",
    "mmp.ref": "manubot.cite.curie.Handler_CURIE",
    "mmrrc": "manubot.cite.curie.Handler_CURIE",
    "mmsinc": "manubot.cite.curie.Handler_CURIE",
    "mmusdv": "manubot.cite.curie.Handler_CURIE",
    "mo": "manubot.cite.curie.Handler_CURIE",
    "mobidb": "manubot.cite.curie.Handler_CURIE",
    "mod": "manubot.cite.curie.Handler_CURIE",
    "modeldb": "manubot.cite.curie.Handler_CURIE",
    "modeldb.concept": "manubot.cite.curie.Handler_CURIE",
    "molbase": "manubot.cite.curie.Handler_CURIE",
    "molmedb": "manubot.cite.curie.Handler_CURIE",
    "molmovdb": "manubot.cite.curie.Handler_CURIE",
    "mondo": "manubot.cite.curie.Handler_CURIE",
    "mop": "manubot.cite.curie.Handler_CURIE",
    "morpheus": "manubot.cite.curie.Handler_CURIE",
    "mosaic": "manubot.cite.curie.Handler_CURIE",
    "mp": "manubot.cite.curie.Handler_CURIE",
    "mpath": "manubot.cite.curie.Handler_CURIE",
    "mpid": "manubot.cite.curie.Handler_CURIE",
    "mpidb": "manubot.cite.curie.Handler_CURIE",
    "mpio": "manubot.cite.curie.Handler_CURIE",
    "mro": "manubot.cite.curie.Handler_CURIE",
    "ms": "manubot.cite.curie.Handler_CURIE",
    "msh": "manubot.cite.curie.Handler_CURIE",
    "msh2010_2010_02_22": "manubot.cite.curie.Handler_CURIE",
    "msig": "manubot.cite.curie.Handler_CURIE",
    "msigdb": "manubot.cite.curie.Handler_CURIE",
    "msio": "manubot.cite.curie.Handler_CURIE",
    "mtbd": "manubot.cite.curie.Handler_CURIE",
    "mthicd9_2006": "manubot.cite.curie.Handler_CURIE",
    "multicellds": "manubot.cite.curie.Handler_CURIE",
    "multicellds.cell_line": "manubot.cite.curie.Handler_CURIE",
    "multicellds.collection": "manubot.cite.curie.Handler_CURIE",
    "multicellds.snapshot": "manubot.cite.curie.Handler_CURIE",
    "mw.project": "manubot.cite.curie.Handler_CURIE",
    "mw.study": "manubot.cite.curie.Handler_CURIE",
    "myco.lepra": "manubot.cite.curie.Handler_CURIE",
    "myco.marinum": "manubot.cite.curie.Handler_CURIE",
    "myco.smeg": "manubot.cite.curie.Handler_CURIE",
    "myco.tuber": "manubot.cite.curie.Handler_CURIE",
    "mycobank": "manubot.cite.curie.Handler_CURIE",
    "mzspec": "manubot.cite.curie.Handler_CURIE",
    "n2t": "manubot.cite.curie.Handler_CURIE",
    "napdi": "manubot.cite.curie.Handler_CURIE",
    "napp": "manubot.cite.curie.Handler_CURIE",
    "narcis": "manubot.cite.curie.Handler_CURIE",
    "nasc": "manubot.cite.curie.Handler_CURIE",
    "nbn": "manubot.cite.curie.Handler_CURIE",
    "nbo": "manubot.cite.curie.Handler_CURIE",
    "nbrc": "manubot.cite.curie.Handler_CURIE",
    "ncats.bioplanet": "manubot.cite.curie.Handler_CURIE",
    "ncats.drug": "manubot.cite.curie.Handler_CURIE",
    "ncbi.assembly": "manubot.cite.curie.Handler_CURIE",
    "ncbi.genome": "manubot.cite.curie.Handler_CURIE",
    "ncbi.gi": "manubot.cite.curie.Handler_CURIE",
    "ncbi.resource": "manubot.cite.curie.Handler_CURIE",
    "ncbi_geneid": "manubot.cite.curie.Handler_CURIE",
    "ncbi_gi": "manubot.cite.curie.Handler_CURIE",
    "ncbi_taxid": "manubot.cite.curie.Handler_CURIE",
    "ncbi_taxon_id": "manubot.cite.curie.Handler_CURIE",
    "ncbibook": "manubot.cite.curie.Handler_CURIE",
    "ncbigene": "manubot.cite.curie.Handler_CURIE",
    "ncbigi": "manubot.cite.curie.Handler_CURIE",
    "ncbiprotein": "manubot.cite.curie.Handler_CURIE",
    "ncbitaxon": "manubot.cite.curie.Handler_CURIE",
    "nci": "manubot.cite.curie.Handler_CURIE",
    "nci2004_11_17": "manubot.cite.curie.Handler_CURIE",
    "nci_thesaurus": "manubot.cite.curie.Handler_CURIE",
    "ncim": "manubot.cite.curie.Handler_CURIE",
    "ncit": "manubot.cite.curie.Handler_CURIE",
    "ncit_thesaurus": "manubot.cite.curie.Handler_CURIE",
    "ncithesaurus": "manubot.cite.curie.Handler_CURIE",
    "ncitm": "manubot.cite.curie.Handler_CURIE",
    "ncitt": "manubot.cite.curie.Handler_CURIE",
    "ncro": "manubot.cite.curie.Handler_CURIE",
    "ndc": "manubot.cite.curie.Handler_CURIE",
    "nddf": "manubot.cite.curie.Handler_CURIE",
    "ndex": "manubot.cite.curie.Handler_CURIE",
    "ndf-rt": "manubot.cite.curie.Handler_CURIE",
    "ndfrt": "manubot.cite.curie.Handler_CURIE",
    "nembase": "manubot.cite.curie.Handler_CURIE",
    "nemo": "manubot.cite.curie.Handler_CURIE",
    "neurolex": "manubot.cite.curie.Handler_CURIE",
    "neuromorpho": "manubot.cite.curie.Handler_CURIE",
    "neuroname": "manubot.cite.curie.Handler_CURIE",
    "neuronames": "manubot.cite.curie.Handler_CURIE",
    "neurondb": "manubot.cite.curie.Handler_CURIE",
    "neurovault.collection": "manubot.cite.curie.Handler_CURIE",
    "neurovault.image": "manubot.cite.curie.Handler_CURIE",
    "nextdb": "manubot.cite.curie.Handler_CURIE",
    "nextprot": "manubot.cite.curie.Handler_CURIE",
    "nextprot.family": "manubot.cite.curie.Handler_CURIE",
    "ngl": "manubot.cite.curie.Handler_CURIE",
    "nhcdr": "manubot.cite.curie.Handler_CURIE",
    "niaest": "manubot.cite.curie.Handler_CURIE",
    "nif.cell": "manubot.cite.curie.Handler_CURIE",
    "nif.dysfunction": "manubot.cite.curie.Handler_CURIE",
    "nif.ext": "manubot.cite.curie.Handler_CURIE",
    "nif.grossanatomy": "manubot.cite.curie.Handler_CURIE",
    "nif.std": "manubot.cite.curie.Handler_CURIE",
    "nif_subcellular": "manubot.cite.curie.Handler_CURIE",
    "nifext": "manubot.cite.curie.Handler_CURIE",
    "nifstd": "manubot.cite.curie.Handler_CURIE",
    "nihreporter.project": "manubot.cite.curie.Handler_CURIE",
    "nlm": "manubot.cite.curie.Handler_CURIE",
    "nlx": "manubot.cite.curie.Handler_CURIE",
    "nlx.anat": "manubot.cite.curie.Handler_CURIE",
    "nlx.br": "manubot.cite.curie.Handler_CURIE",
    "nlx.cell": "manubot.cite.curie.Handler_CURIE",
    "nlx.chem": "manubot.cite.curie.Handler_CURIE",
    "nlx.dys": "manubot.cite.curie.Handler_CURIE",
    "nlx.func": "manubot.cite.curie.Handler_CURIE",
    "nlx.inv": "manubot.cite.curie.Handler_CURIE",
    "nlx.mol": "manubot.cite.curie.Handler_CURIE",
    "nlx.oen": "manubot.cite.curie.Handler_CURIE",
    "nlx.org": "manubot.cite.curie.Handler_CURIE",
    "nlx.qual": "manubot.cite.curie.Handler_CURIE",
    "nlx.res": "manubot.cite.curie.Handler_CURIE",
    "nlx.sub": "manubot.cite.curie.Handler_CURIE",
    "nlxbr": "manubot.cite.curie.Handler_CURIE",
    "nlxcell": "manubot.cite.curie.Handler_CURIE",
    "nlxchem": "manubot.cite.curie.Handler_CURIE",
    "nlxfunc": "manubot.cite.curie.Handler_CURIE",
    "nlxinv": "manubot.cite.curie.Handler_CURIE",
    "nlxmol": "manubot.cite.curie.Handler_CURIE",
    "nlxoen": "manubot.cite.curie.Handler_CURIE",
    "nlxorg": "manubot.cite.curie.Handler_CURIE",
    "nlxqual": "manubot.cite.curie.Handler_CURIE",
    "nlxres": "manubot.cite.curie.Handler_CURIE",
    "nlxsub": "manubot.cite.curie.Handler_CURIE",
    "nmdc": "manubot.cite.curie.Handler_CURIE",
    "nmpdr": "manubot.cite.curie.Handler_CURIE",
    "nmr": "manubot.cite.curie.Handler_CURIE",
    "nmrcv": "manubot.cite.curie.Handler_CURIE",
    "nmrshiftdb2": "manubot.cite.curie.Handler_CURIE",
    "noaa": "manubot.cite.curie.Handler_CURIE",
    "nomen": "manubot.cite.curie.Handler_CURIE",
    "noncodev3": "manubot.cite.curie.Handler_CURIE",
    "noncodev4.gene": "manubot.cite.curie.Handler_CURIE",
    "noncodev4.rna": "manubot.cite.curie.Handler_CURIE",
    "norine": "manubot.cite.curie.Handler_CURIE",
    "novus": "manubot.cite.curie.Handler_CURIE",
    "npo": "manubot.cite.curie.Handler_CURIE",
    "nsc": "manubot.cite.curie.Handler_CURIE",
    "nsf.award": "manubot.cite.curie.Handler_CURIE",
    "nuclearbd": "manubot.cite.curie.Handler_CURIE",
    "nucleotide": "manubot.cite.curie.Handler_CURIE",
    "nui": "manubot.cite.curie.Handler_CURIE",
    "nxp": "manubot.cite.curie.Handler_CURIE",
    "nxpfa": "manubot.cite.curie.Handler_CURIE",
    "oa": "manubot.cite.curie.Handler_CURIE",
    "oae": "manubot.cite.curie.Handler_CURIE",
    "oarcs": "manubot.cite.curie.Handler_CURIE",
    "oba": "manubot.cite.curie.Handler_CURIE",
    "obcs": "manubot.cite.curie.Handler_CURIE",
    "obi": "manubot.cite.curie.Handler_CURIE",
    "obib": "manubot.cite.curie.Handler_CURIE",
    "obo": "manubot.cite.curie.Handler_CURIE",
    "obo_rel": "manubot.cite.curie.Handler_CURIE",
    "oboformat": "manubot.cite.curie.Handler_CURIE",
    "oboinowl": "manubot.cite.curie.Handler_CURIE",
    "oborel": "manubot.cite.curie.Handler_CURIE",
    "occ": "manubot.cite.curie.Handler_CURIE",
    "oci": "manubot.cite.curie.Handler_CURIE",
    "ocid": "manubot.cite.curie.Handler_CURIE",
    "oclc": "manubot.cite.curie.Handler_CURIE",
    "odam": "manubot.cite.curie.Handler_CURIE",
    "odc.sci": "manubot.cite.curie.Handler_CURIE",
    "odc.tbi": "manubot.cite.curie.Handler_CURIE",
    "odor": "manubot.cite.curie.Handler_CURIE",
    "ogg": "manubot.cite.curie.Handler_CURIE",
    "ogi": "manubot.cite.curie.Handler_CURIE",
    "ogi.owl": "manubot.cite.curie.Handler_CURIE",
    "ogms": "manubot.cite.curie.Handler_CURIE",
    "ogsf": "manubot.cite.curie.Handler_CURIE",
    "ohd": "manubot.cite.curie.Handler_CURIE",
    "ohmi": "manubot.cite.curie.Handler_CURIE",
    "ohpi": "manubot.cite.curie.Handler_CURIE",
    "oid": "manubot.cite.curie.Handler_CURIE",
    "oio": "manubot.cite.curie.Handler_CURIE",
    "olatdv": "manubot.cite.curie.Handler_CURIE",
    "om": "manubot.cite.curie.Handler_CURIE",
    "oma.grp": "manubot.cite.curie.Handler_CURIE",
    "oma.hog": "manubot.cite.curie.Handler_CURIE",
    "oma.protein": "manubot.cite.curie.Handler_CURIE",
    "omia": "manubot.cite.curie.Handler_CURIE",
    "omiabis": "manubot.cite.curie.Handler_CURIE",
    "omim": "manubot.cite.curie.Handler_CURIE",
    "omim.ps": "manubot.cite.curie.Handler_CURIE",
    "omimps": "manubot.cite.curie.Handler_CURIE",
    "omit": "manubot.cite.curie.Handler_CURIE",
    "omo": "manubot.cite.curie.Handler_CURIE",
    "omop": "manubot.cite.curie.Handler_CURIE",
    "omp": "manubot.cite.curie.Handler_CURIE",
    "omrse": "manubot.cite.curie.Handler_CURIE",
    "oncotree": "manubot.cite.curie.Handler_CURIE",
    "one": "manubot.cite.curie.Handler_CURIE",
    "ons": "manubot.cite.curie.Handler_CURIE",
    "ontoavida": "manubot.cite.curie.Handler_CURIE",
    "ontoneo": "manubot.cite.curie.Handler_CURIE",
    "oostt": "manubot.cite.curie.Handler_CURIE",
    "opb": "manubot.cite.curie.Handler_CURIE",
    "openalex": "manubot.cite.curie.Handler_CURIE",
    "opl": "manubot.cite.curie.Handler_CURIE",
    "opm": "manubot.cite.curie.Handler_CURIE",
    "opmi": "manubot.cite.curie.Handler_CURIE",
    "orcid": "manubot.cite.curie.Handler_CURIE",
    "ordb": "manubot.cite.curie.Handler_CURIE",
    "ordo": "manubot.cite.curie.Handler_CURIE",
    "oridb.sacch": "manubot.cite.curie.Handler_CURIE",
    "oridb.schizo": "manubot.cite.curie.Handler_CURIE",
    "ornaseq": "manubot.cite.curie.Handler_CURIE",
    "orpha": "manubot.cite.curie.Handler_CURIE",
    "orphanet": "manubot.cite.curie.Handler_CURIE",
    "orphanet.ordo": "manubot.cite.curie.Handler_CURIE",
    "orth": "manubot.cite.curie.Handler_CURIE",
    "orthodb": "manubot.cite.curie.Handler_CURIE",
    "oryzabase.gene": "manubot.cite.curie.Handler_CURIE",
    "oryzabase.mutant": "manubot.cite.curie.Handler_CURIE",
    "oryzabase.reference": "manubot.cite.curie.Handler_CURIE",
    "oryzabase.stage": "manubot.cite.curie.Handler_CURIE",
    "oryzabase.strain": "manubot.cite.curie.Handler_CURIE",
    "oslc": "manubot.cite.curie.Handler_CURIE",
    "otl": "manubot.cite.curie.Handler_CURIE",
    "otol": "manubot.cite.curie.Handler_CURIE",
    "ovae": "manubot.cite.curie.Handler_CURIE",
    "owl": "manubot.cite.curie.Handler_CURIE",
    "p3db.protein": "manubot.cite.curie.Handler_CURIE",
    "p3db.site": "manubot.cite.curie.Handler_CURIE",
    "paleodb": "manubot.cite.curie.Handler_CURIE",
    "pandit": "manubot.cite.curie.Handler_CURIE",
    "panorama": "manubot.cite.curie.Handler_CURIE",
    "panther.family": "manubot.cite.curie.Handler_CURIE",
    "panther.node": "manubot.cite.curie.Handler_CURIE",
    "panther.pathway": "manubot.cite.curie.Handler_CURIE",
    "panther.pthcmp": "manubot.cite.curie.Handler_CURIE",
    "pao": "manubot.cite.curie.Handler_CURIE",
    "pass2": "manubot.cite.curie.Handler_CURIE",
    "patent": "manubot.cite.curie.Handler_CURIE",
    "pathbank": "manubot.cite.curie.Handler_CURIE",
    "pathguide": "manubot.cite.curie.Handler_CURIE",
    "pathoplant": "manubot.cite.curie.Handler_CURIE",
    "pathwaycommons": "manubot.cite.curie.Handler_CURIE",
    "pato": "manubot.cite.curie.Handler_CURIE",
    "pav": "manubot.cite.curie.Handler_CURIE",
    "paxdb.organism": "manubot.cite.curie.Handler_CURIE",
    "paxdb.protein": "manubot.cite.curie.Handler_CURIE",
    "pazar": "manubot.cite.curie.Handler_CURIE",
    "pba": "manubot.cite.curie.Handler_CURIE",
    "pcl": "manubot.cite.curie.Handler_CURIE",
    "pco": "manubot.cite.curie.Handler_CURIE",
    "pd_st": "manubot.cite.curie.Handler_CURIE",
    "pdb": "manubot.cite.curie.Handler_CURIE",
    "pdb-ccd": "manubot.cite.curie.Handler_CURIE",
    "pdb.ligand": "manubot.cite.curie.Handler_CURIE",
    "pdb_chem_id": "manubot.cite.curie.Handler_CURIE",
    "pdbe": "manubot.cite.curie.Handler_CURIE",
    "pdbechem": "manubot.cite.curie.Handler_CURIE",
    "pdbj": "manubot.cite.curie.Handler_CURIE",
    "pdbsum": "manubot.cite.curie.Handler_CURIE",
    "pdc.study": "manubot.cite.curie.Handler_CURIE",
    "pdro": "manubot.cite.curie.Handler_CURIE",
    "pdumdv": "manubot.cite.curie.Handler_CURIE",
    "peco": "manubot.cite.curie.Handler_CURIE",
    "ped": "manubot.cite.curie.Handler_CURIE",
    "ped.ensemble": "manubot.cite.curie.Handler_CURIE",
    "peff": "manubot.cite.curie.Handler_CURIE",
    "pennsieve": "manubot.cite.curie.Handler_CURIE",
    "pepbank": "manubot.cite.curie.Handler_CURIE",
    "peptideatlas": "manubot.cite.curie.Handler_CURIE",
    "peptideatlas.dataset": "manubot.cite.curie.Handler_CURIE",
    "perkinelmer": "manubot.cite.curie.Handler_CURIE",
    "peroxibase": "manubot.cite.curie.Handler_CURIE",
    "pesticides": "manubot.cite.curie.Handler_CURIE",
    "pf": "manubot.cite.curie.Handler_CURIE",
    "pfam": "manubot.cite.curie.Handler_CURIE",
    "pfam.clan": "manubot.cite.curie.Handler_CURIE",
    "pfr": "manubot.cite.curie.Handler_CURIE",
    "pgdso": "manubot.cite.curie.Handler_CURIE",
    "pgs": "manubot.cite.curie.Handler_CURIE",
    "pgx": "manubot.cite.curie.Handler_CURIE",
    "pharmacodb.cell": "manubot.cite.curie.Handler_CURIE",
    "pharmacodb.dataset": "manubot.cite.curie.Handler_CURIE",
    "pharmacodb.tissue": "manubot.cite.curie.Handler_CURIE",
    "pharmgkb.disease": "manubot.cite.curie.Handler_CURIE",
    "pharmgkb.drug": "manubot.cite.curie.Handler_CURIE",
    "pharmgkb.gene": "manubot.cite.curie.Handler_CURIE",
    "pharmgkb.pathways": "manubot.cite.curie.Handler_CURIE",
    "pharmvar": "manubot.cite.curie.Handler_CURIE",
    "phenolexplorer": "manubot.cite.curie.Handler_CURIE",
    "phenx": "manubot.cite.curie.Handler_CURIE",
    "phenxtoolkit": "manubot.cite.curie.Handler_CURIE",
    "phipo": "manubot.cite.curie.Handler_CURIE",
    "phosphopoint.kinase": "manubot.cite.curie.Handler_CURIE",
    "phosphopoint.protein": "manubot.cite.curie.Handler_CURIE",
    "phosphosite.protein": "manubot.cite.curie.Handler_CURIE",
    "phosphosite.residue": "manubot.cite.curie.Handler_CURIE",
    "phylomedb": "manubot.cite.curie.Handler_CURIE",
    "phytozome.locus": "manubot.cite.curie.Handler_CURIE",
    "pibase": "manubot.cite.curie.Handler_CURIE",
    "pid": "manubot.cite.curie.Handler_CURIE",
    "pid.pathway": "manubot.cite.curie.Handler_CURIE",
    "pigqtldb": "manubot.cite.curie.Handler_CURIE",
    "pina": "manubot.cite.curie.Handler_CURIE",
    "piroplasma": "manubot.cite.curie.Handler_CURIE",
    "pirsf": "manubot.cite.curie.Handler_CURIE",
    "pkdb": "manubot.cite.curie.Handler_CURIE",
    "plana": "manubot.cite.curie.Handler_CURIE",
    "planp": "manubot.cite.curie.Handler_CURIE",
    "planttfdb": "manubot.cite.curie.Handler_CURIE",
    "plasmodb": "manubot.cite.curie.Handler_CURIE",
    "plo": "manubot.cite.curie.Handler_CURIE",
    "pmap.cutdb": "manubot.cite.curie.Handler_CURIE",
    "pmap.substratedb": "manubot.cite.curie.Handler_CURIE",
    "pmc": "manubot.cite.pubmed.Handler_PMC",
    "pmcid": "manubot.cite.pubmed.Handler_PMC",
    "pmdb": "manubot.cite.curie.Handler_CURIE",
    "pmid": "manubot.cite.pubmed.Handler_PubMed",
    "pmp": "manubot.cite.curie.Handler_CURIE",
    "pmr": "manubot.cite.curie.Handler_CURIE",
    "pmr.workspace": "manubot.cite.curie.Handler_CURIE",
    "po": "manubot.cite.curie.Handler_CURIE",
    "pocketome": "manubot.cite.curie.Handler_CURIE",
    "polbase": "manubot.cite.curie.Handler_CURIE",
    "pombase": "manubot.cite.curie.Handler_CURIE",
    "poro": "manubot.cite.curie.Handler_CURIE",
    "ppdb": "manubot.cite.curie.Handler_CURIE",
    "ppo": "manubot.cite.curie.Handler_CURIE",
    "ppr": "manubot.cite.curie.Handler_CURIE",
    "pr": "manubot.cite.curie.Handler_CURIE",
    "prefixcommons": "manubot.cite.curie.Handler_CURIE",
    "pride": "manubot.cite.curie.Handler_CURIE",
    "pride.project": "manubot.cite.curie.Handler_CURIE",
    "prints": "manubot.cite.curie.Handler_CURIE",
    "pro": "manubot.cite.curie.Handler_CURIE",
    "probesanddrugs": "manubot.cite.curie.Handler_CURIE",
    "probonto": "manubot.cite.curie.Handler_CURIE",
    "proco": "manubot.cite.curie.Handler_CURIE",
    "prodom": "manubot.cite.curie.Handler_CURIE",
    "progenetix": "manubot.cite.curie.Handler_CURIE",
    "proglyc": "manubot.cite.curie.Handler_CURIE",
    "propreo": "manubot.cite.curie.Handler_CURIE",
    "prosite": "manubot.cite.curie.Handler_CURIE",
    "protclustdb": "manubot.cite.curie.Handler_CURIE",
    "protcom": "manubot.cite.curie.Handler_CURIE",
    "proteomicsdb.peptide": "manubot.cite.curie.Handler_CURIE",
    "proteomicsdb.protein": "manubot.cite.curie.Handler_CURIE",
    "protonet.cluster": "manubot.cite.curie.Handler_CURIE",
    "protonet.proteincard": "manubot.cite.curie.Handler_CURIE",
    "prov": "manubot.cite.curie.Handler_CURIE",
    "ps": "manubot.cite.curie.Handler_CURIE",
    "pscdb": "manubot.cite.curie.Handler_CURIE",
    "psdo": "manubot.cite.curie.Handler_CURIE",
    "pseudogene": "manubot.cite.curie.Handler_CURIE",
    "pseudogene.org": "manubot.cite.curie.Handler_CURIE",
    "pseudomonas": "manubot.cite.curie.Handler_CURIE",
    "psi-mi": "manubot.cite.curie.Handler_CURIE",
    "psi-mod": "manubot.cite.curie.Handler_CURIE",
    "psipar": "manubot.cite.curie.Handler_CURIE",
    "pso": "manubot.cite.curie.Handler_CURIE",
    "ptm": "manubot.cite.curie.Handler_CURIE",
    "pubchem": "manubot.cite.curie.Handler_CURIE",
    "pubchem.bioassay": "manubot.cite.curie.Handler_CURIE",
    "pubchem.cell": "manubot.cite.curie.Handler_CURIE",
    "pubchem.classification": "manubot.cite.curie.Handler_CURIE",
    "pubchem.compound": "manubot.cite.curie.Handler_CURIE",
    "pubchem.element": "manubot.cite.curie.Handler_CURIE",
    "pubchem.substance": "manubot.cite.curie.Handler_CURIE",
    "pubchem_cid": "manubot.cite.curie.Handler_CURIE",
    "pubchem_compound_cid": "manubot.cite.curie.Handler_CURIE",
    "pubchem_id": "manubot.cite.curie.Handler_CURIE",
    "publons.researcher": "manubot.cite.curie.Handler_CURIE",
    "pubmed": "manubot.cite.pubmed.Handler_PubMed",
    "puro": "manubot.cite.curie.Handler_CURIE",
    "pw": "manubot.cite.curie.Handler_CURIE",
    "pwo": "manubot.cite.curie.Handler_CURIE",
    "px": "manubot.cite.curie.Handler_CURIE",
    "pypi": "manubot.cite.curie.Handler_CURIE",
    "qb": "manubot.cite.curie.Handler_CURIE",
    "qtldb": "manubot.cite.curie.Handler_CURIE",
    "qudt": "manubot.cite.curie.Handler_CURIE",
    "radiomics": "manubot.cite.curie.Handler_CURIE",
    "radlex": "manubot.cite.curie.Handler_CURIE",
    "rapdb.locus": "manubot.cite.curie.Handler_CURIE",
    "rapdb.transcript": "manubot.cite.curie.Handler_CURIE",
    "ratmap": "manubot.cite.curie.Handler_CURIE",
    "rbk": "manubot.cite.curie.Handler_CURIE",
    "rbo": "manubot.cite.curie.Handler_CURIE",
    "rcb": "manubot.cite.curie.Handler_CURIE",
    "rcsb_pdb": "manubot.cite.curie.Handler_CURIE",
    "rdf": "manubot.cite.curie.Handler_CURIE",
    "rdfs": "manubot.cite.curie.Handler_CURIE",
    "rdo": "manubot.cite.curie.Handler_CURIE",
    "re": "manubot.cite.curie.Handler_CURIE",
    "re3data": "manubot.cite.curie.Handler_CURIE",
    "react": "manubot.cite.curie.Handler_CURIE",
    "reactome": "manubot.cite.curie.Handler_CURIE",
    "rebase": "manubot.cite.curie.Handler_CURIE",
    "receptome.family": "manubot.cite.curie.Handler_CURIE",
    "redfly": "manubot.cite.curie.Handler_CURIE",
    "refseq": "manubot.cite.curie.Handler_CURIE",
    "refseq_prot": "manubot.cite.curie.Handler_CURIE",
    "reo": "manubot.cite.curie.Handler_CURIE",
    "repeatsdb.protein": "manubot.cite.curie.Handler_CURIE",
    "repeatsdb.structure": "manubot.cite.curie.Handler_CURIE",
    "reproduceme": "manubot.cite.curie.Handler_CURIE",
    "resid": "manubot.cite.curie.Handler_CURIE",
    "retired_ehdaa2": "manubot.cite.curie.Handler_CURIE",
    "rex": "manubot.cite.curie.Handler_CURIE",
    "rfam": "manubot.cite.curie.Handler_CURIE",
    "rfc": "manubot.cite.curie.Handler_CURIE",
    "rgap": "manubot.cite.curie.Handler_CURIE",
    "rgd": "manubot.cite.curie.Handler_CURIE",
    "rgd.qtl": "manubot.cite.curie.Handler_CURIE",
    "rgd.strain": "manubot.cite.curie.Handler_CURIE",
    "rhea": "manubot.cite.curie.Handler_CURIE",
    "ribocenter": "manubot.cite.curie.Handler_CURIE",
    "ribocentre": "manubot.cite.curie.Handler_CURIE",
    "ricecyc": "manubot.cite.curie.Handler_CURIE",
    "ricegap": "manubot.cite.curie.Handler_CURIE",
    "ricenetdb.compound": "manubot.cite.curie.Handler_CURIE",
    "ricenetdb.gene": "manubot.cite.curie.Handler_CURIE",
    "ricenetdb.mirna": "manubot.cite.curie.Handler_CURIE",
    "ricenetdb.protein": "manubot.cite.curie.Handler_CURIE",
    "ricenetdb.reaction": "manubot.cite.curie.Handler_CURIE",
    "rism": "manubot.cite.curie.Handler_CURIE",
    "rna_sstrand": "manubot.cite.curie.Handler_CURIE",
    "rnacentral": "manubot.cite.curie.Handler_CURIE",
    "rnajunction": "manubot.cite.curie.Handler_CURIE",
    "rnaloops": "manubot.cite.curie.Handler_CURIE",
    "rnamod": "manubot.cite.curie.Handler_CURIE",
    "rnamods": "manubot.cite.curie.Handler_CURIE",
    "rnao": "manubot.cite.curie.Handler_CURIE",
    "ro": "manubot.cite.curie.Handler_CURIE",
    "ro_proposed_relation": "manubot.cite.curie.Handler_CURIE",
    "roleo": "manubot.cite.curie.Handler_CURIE",
    "ror": "manubot.cite.curie.Handler_CURIE",
    "rouge": "manubot.cite.curie.Handler_CURIE",
    "rrid": "manubot.cite.curie.Handler_CURIE",
    "rs": "manubot.cite.curie.Handler_CURIE",
    "runbiosimulations": "manubot.cite.curie.Handler_CURIE",
    "rxcui": "manubot.cite.curie.Handler_CURIE",
    "rxno": "manubot.cite.curie.Handler_CURIE",
    "rxnorm": "manubot.cite.curie.Handler_CURIE",
    "s_mart_db": "manubot.cite.curie.Handler_CURIE",
    "sabio-rk": "manubot.cite.curie.Handler_CURIE",
    "sabiork.compound": "manubot.cite.curie.Handler_CURIE",
    "sabiork.ec": "manubot.cite.curie.Handler_CURIE",
    "sabiork.kineticrecord": "manubot.cite.curie.Handler_CURIE",
    "sabiork.reaction": "manubot.cite.curie.Handler_CURIE",
    "salk": "manubot.cite.curie.Handler_CURIE",
    "sao": "manubot.cite.curie.Handler_CURIE",
    "sasbdb": "manubot.cite.curie.Handler_CURIE",
    "sbo": "manubot.cite.curie.Handler_CURIE",
    "scdo": "manubot.cite.curie.Handler_CURIE",
    "schem": "manubot.cite.curie.Handler_CURIE",
    "schema": "manubot.cite.curie.Handler_CURIE",
    "schemaorg": "manubot.cite.curie.Handler_CURIE",
    "scholia.resource": "manubot.cite.curie.Handler_CURIE",
    "scicrunch": "manubot.cite.curie.Handler_CURIE",
    "scomp": "manubot.cite.curie.Handler_CURIE",
    "scop": "manubot.cite.curie.Handler_CURIE",
    "scoro": "manubot.cite.curie.Handler_CURIE",
    "scpd": "manubot.cite.curie.Handler_CURIE",
    "scr": "manubot.cite.curie.Handler_CURIE",
    "scretf": "manubot.cite.curie.Handler_CURIE",
    "sctid": "manubot.cite.curie.Handler_CURIE",
    "sctid_2010_1_31": "manubot.cite.curie.Handler_CURIE",
    "sdap": "manubot.cite.curie.Handler_CURIE",
    "sdbs": "manubot.cite.curie.Handler_CURIE",
    "sdgio": "manubot.cite.curie.Handler_CURIE",
    "sdis": "manubot.cite.curie.Handler_CURIE",
    "secondary_cas_rn": "manubot.cite.curie.Handler_CURIE",
    "sedml.format": "manubot.cite.curie.Handler_CURIE",
    "sedml.language": "manubot.cite.curie.Handler_CURIE",
    "seed": "manubot.cite.curie.Handler_CURIE",
    "seed.compound": "manubot.cite.curie.Handler_CURIE",
    "seed.reaction": "manubot.cite.curie.Handler_CURIE",
    "sep": "manubot.cite.curie.Handler_CURIE",
    "sepio": "manubot.cite.curie.Handler_CURIE",
    "sfam": "manubot.cite.curie.Handler_CURIE",
    "sgd": "manubot.cite.curie.Handler_CURIE",
    "sgd.pathways": "manubot.cite.curie.Handler_CURIE",
    "sgn": "manubot.cite.curie.Handler_CURIE",
    "sh": "manubot.cite.curie.Handler_CURIE",
    "shacl": "manubot.cite.curie.Handler_CURIE",
    "shareloc": "manubot.cite.curie.Handler_CURIE",
    "sharkipedia.species": "manubot.cite.curie.Handler_CURIE",
    "sharkipedia.trait": "manubot.cite.curie.Handler_CURIE",
    "sharkipedia.trend": "manubot.cite.curie.Handler_CURIE",
    "sheepqtldb": "manubot.cite.curie.Handler_CURIE",
    "shex": "manubot.cite.curie.Handler_CURIE",
    "shibase": "manubot.cite.curie.Handler_CURIE",
    "shortdoi": "manubot.cite.doi.Handler_DOI",
    "sibo": "manubot.cite.curie.Handler_CURIE",
    "sider.drug": "manubot.cite.curie.Handler_CURIE",
    "sider.effect": "manubot.cite.curie.Handler_CURIE",
    "sigmaaldrich": "manubot.cite.curie.Handler_CURIE",
    "signaling-gateway": "manubot.cite.curie.Handler_CURIE",
    "signor": "manubot.cite.curie.Handler_CURIE",
    "sio": "manubot.cite.curie.Handler_CURIE",
    "sisu": "manubot.cite.curie.Handler_CURIE",
    "sitex": "manubot.cite.curie.Handler_CURIE",
    "skip": "manubot.cite.curie.Handler_CURIE",
    "skos": "manubot.cite.curie.Handler_CURIE",
    "skosxl": "manubot.cite.curie.Handler_CURIE",
    "slkbase": "manubot.cite.curie.Handler_CURIE",
    "slm": "manubot.cite.curie.Handler_CURIE",
    "smart": "manubot.cite.curie.Handler_CURIE",
    "smid": "manubot.cite.curie.Handler_CURIE",
    "smid-db": "manubot.cite.curie.Handler_CURIE",
    "smp": "manubot.cite.curie.Handler_CURIE",
    "smpdb": "manubot.cite.curie.Handler_CURIE",
    "snap": "manubot.cite.curie.Handler_CURIE",
    "snomect": "manubot.cite.curie.Handler_CURIE",
    "snomed": "manubot.cite.curie.Handler_CURIE",
    "snomed_ct": "manubot.cite.curie.Handler_CURIE",
    "snomed_ct_us_2018_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct": "manubot.cite.curie.Handler_CURIE",
    "snomedct_2005_07_31": "manubot.cite.curie.Handler_CURIE",
    "snomedct_2010_1_31": "manubot.cite.curie.Handler_CURIE",
    "snomedct_2020_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2015_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2016_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2018_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2018_09_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2019_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2019_09_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2020_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2020_09_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2021_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2021_07_31": "manubot.cite.curie.Handler_CURIE",
    "snomedct_us_2021_09_01": "manubot.cite.curie.Handler_CURIE",
    "snomedctct": "manubot.cite.curie.Handler_CURIE",
    "snomedctct_2018_03_01": "manubot.cite.curie.Handler_CURIE",
    "snomedctct_2019_03_01": "manubot.cite.curie.Handler_CURIE",
    "snornabase": "manubot.cite.curie.Handler_CURIE",
    "snowmedct": "manubot.cite.curie.Handler_CURIE",
    "snowmedct_us": "manubot.cite.curie.Handler_CURIE",
    "snowmedct_us_2018_03_01": "manubot.cite.curie.Handler_CURIE",
    "snp2tfbs": "manubot.cite.curie.Handler_CURIE",
    "snp500cancer": "manubot.cite.curie.Handler_CURIE",
    "so": "manubot.cite.curie.Handler_CURIE",
    "sopharm": "manubot.cite.curie.Handler_CURIE",
    "soybase": "manubot.cite.curie.Handler_CURIE",
    "sp_di": "manubot.cite.curie.Handler_CURIE",
    "sp_kw": "manubot.cite.curie.Handler_CURIE",
    "sp_sl": "manubot.cite.curie.Handler_CURIE",
    "sp_var": "manubot.cite.curie.Handler_CURIE",
    "spbase": "manubot.cite.curie.Handler_CURIE",
    "spd": "manubot.cite.curie.Handler_CURIE",
    "spdx": "manubot.cite.curie.Handler_CURIE",
    "sphn": "manubot.cite.curie.Handler_CURIE",
    "spike.map": "manubot.cite.curie.Handler_CURIE",
    "splash": "manubot.cite.curie.Handler_CURIE",
    "splicenest": "manubot.cite.curie.Handler_CURIE",
    "spp": "manubot.cite.curie.Handler_CURIE",
    "sprint": "manubot.cite.curie.Handler_CURIE",
    "srao": "manubot.cite.curie.Handler_CURIE",
    "ssbd.dataset": "manubot.cite.curie.Handler_CURIE",
    "ssbd.project": "manubot.cite.curie.Handler_CURIE",
    "sstoss": "manubot.cite.curie.Handler_CURIE",
    "stap": "manubot.cite.curie.Handler_CURIE",
    "stato": "manubot.cite.curie.Handler_CURIE",
    "stitch": "manubot.cite.curie.Handler_CURIE",
    "storedb": "manubot.cite.curie.Handler_CURIE",
    "storedb.dataset": "manubot.cite.curie.Handler_CURIE",
    "storedb.file": "manubot.cite.curie.Handler_CURIE",
    "storedb.study": "manubot.cite.curie.Handler_CURIE",
    "string": "manubot.cite.curie.Handler_CURIE",
    "sty": "manubot.cite.curie.Handler_CURIE",
    "subtilist": "manubot.cite.curie.Handler_CURIE",
    "subtiwiki": "manubot.cite.curie.Handler_CURIE",
    "sugarbind": "manubot.cite.curie.Handler_CURIE",
    "supfam": "manubot.cite.curie.Handler_CURIE",
    "sweetrealm": "manubot.cite.curie.Handler_CURIE",
    "swh": "manubot.cite.curie.Handler_CURIE",
    "swiss-model": "manubot.cite.curie.Handler_CURIE",
    "swisslipid": "manubot.cite.curie.Handler_CURIE",
    "swisslipids": "manubot.cite.curie.Handler_CURIE",
    "swissprot": "manubot.cite.curie.Handler_CURIE",
    "swissregulon": "manubot.cite.curie.Handler_CURIE",
    "swo": "manubot.cite.curie.Handler_CURIE",
    "swrl": "manubot.cite.curie.Handler_CURIE",
    "symp": "manubot.cite.curie.Handler_CURIE",
    "t3db": "manubot.cite.curie.Handler_CURIE",
    "tads": "manubot.cite.curie.Handler_CURIE",
    "tahe": "manubot.cite.curie.Handler_CURIE",
    "tahh": "manubot.cite.curie.Handler_CURIE",
    "tair.gene": "manubot.cite.curie.Handler_CURIE",
    "tair.locus": "manubot.cite.curie.Handler_CURIE",
    "tair.protein": "manubot.cite.curie.Handler_CURIE",
    "tao": "manubot.cite.curie.Handler_CURIE",
    "tao_retired": "manubot.cite.curie.Handler_CURIE",
    "tarbase": "manubot.cite.curie.Handler_CURIE",
    "tax": "manubot.cite.curie.Handler_CURIE",
    "taxid": "manubot.cite.curie.Handler_CURIE",
    "taxon": "manubot.cite.curie.Handler_CURIE",
    "taxonomy": "manubot.cite.curie.Handler_CURIE",
    "taxonomyid": "manubot.cite.curie.Handler_CURIE",
    "taxrank": "manubot.cite.curie.Handler_CURIE",
    "tc": "manubot.cite.curie.Handler_CURIE",
    "tcb": "manubot.cite.curie.Handler_CURIE",
    "tccd": "manubot.cite.curie.Handler_CURIE",
    "tcdb": "manubot.cite.curie.Handler_CURIE",
    "tdr": "manubot.cite.curie.Handler_CURIE",
    "teddy": "manubot.cite.curie.Handler_CURIE",
    "tfclass": "manubot.cite.curie.Handler_CURIE",
    "tgd": "manubot.cite.curie.Handler_CURIE",
    "tgma": "manubot.cite.curie.Handler_CURIE",
    "tgn": "manubot.cite.curie.Handler_CURIE",
    "thermofisher": "manubot.cite.curie.Handler_CURIE",
    "tigrfam": "manubot.cite.curie.Handler_CURIE",
    "time": "manubot.cite.curie.Handler_CURIE",
    "tkg": "manubot.cite.curie.Handler_CURIE",
    "tngb": "manubot.cite.curie.Handler_CURIE",
    "to": "manubot.cite.curie.Handler_CURIE",
    "tokue": "manubot.cite.curie.Handler_CURIE",
    "tol": "manubot.cite.curie.Handler_CURIE",
    "tol.webproj": "manubot.cite.curie.Handler_CURIE",
    "topdb": "manubot.cite.curie.Handler_CURIE",
    "topfind": "manubot.cite.curie.Handler_CURIE",
    "toxoplasma": "manubot.cite.curie.Handler_CURIE",
    "trans": "manubot.cite.curie.Handler_CURIE",
    "transportdb": "manubot.cite.curie.Handler_CURIE",
    "transyt": "manubot.cite.curie.Handler_CURIE",
    "tred": "manubot.cite.curie.Handler_CURIE",
    "treebase": "manubot.cite.curie.Handler_CURIE",
    "treefam": "manubot.cite.curie.Handler_CURIE",
    "trichdb": "manubot.cite.curie.Handler_CURIE",
    "tritrypdb": "manubot.cite.curie.Handler_CURIE",
    "trnadbce": "manubot.cite.curie.Handler_CURIE",
    "ttd.drug": "manubot.cite.curie.Handler_CURIE",
    "ttd.target": "manubot.cite.curie.Handler_CURIE",
    "tto": "manubot.cite.curie.Handler_CURIE",
    "tuberculist": "manubot.cite.curie.Handler_CURIE",
    "txpo": "manubot.cite.curie.Handler_CURIE",
    "uberon": "manubot.cite.curie.Handler_CURIE",
    "ubio.namebank": "manubot.cite.curie.Handler_CURIE",
    "ucsc": "manubot.cite.curie.Handler_CURIE",
    "ucum": "manubot.cite.curie.Handler_CURIE",
    "um-bbd_compid": "manubot.cite.curie.Handler_CURIE",
    "um-bbd_enzymeid": "manubot.cite.curie.Handler_CURIE",
    "um-bbd_pathwayid": "manubot.cite.curie.Handler_CURIE",
    "um-bbd_reactionid": "manubot.cite.curie.Handler_CURIE",
    "um-bbd_ruleid": "manubot.cite.curie.Handler_CURIE",
    "umbbd.compound": "manubot.cite.curie.Handler_CURIE",
    "umbbd.enzyme": "manubot.cite.curie.Handler_CURIE",
    "umbbd.pathway": "manubot.cite.curie.Handler_CURIE",
    "umbbd.reaction": "manubot.cite.curie.Handler_CURIE",
    "umbbd.rule": "manubot.cite.curie.Handler_CURIE",
    "umls": "manubot.cite.curie.Handler_CURIE",
    "umls.cui": "manubot.cite.curie.Handler_CURIE",
    "umls.st": "manubot.cite.curie.Handler_CURIE",
    "umls.sty": "manubot.cite.curie.Handler_CURIE",
    "umls_cui": "manubot.cite.curie.Handler_CURIE",
    "unigene": "manubot.cite.curie.Handler_CURIE",
    "unii": "manubot.cite.curie.Handler_CURIE",
    "unimod": "manubot.cite.curie.Handler_CURIE",
    "uniparc": "manubot.cite.curie.Handler_CURIE",
    "unipathway": "manubot.cite.curie.Handler_CURIE",
    "unipathway.compound": "manubot.cite.curie.Handler_CURIE",
    "unipathway.pathway": "manubot.cite.curie.Handler_CURIE",
    "unipathway.reaction": "manubot.cite.curie.Handler_CURIE",
    "uniprot": "manubot.cite.curie.Handler_CURIE",
    "uniprot.arba": "manubot.cite.curie.Handler_CURIE",
    "uniprot.chain": "manubot.cite.curie.Handler_CURIE",
    "uniprot.database": "manubot.cite.curie.Handler_CURIE",
    "uniprot.db": "manubot.cite.curie.Handler_CURIE",
    "uniprot.disease": "manubot.cite.curie.Handler_CURIE",
    "uniprot.isoform": "manubot.cite.curie.Handler_CURIE",
    "uniprot.journal": "manubot.cite.curie.Handler_CURIE",
    "uniprot.keyword": "manubot.cite.curie.Handler_CURIE",
    "uniprot.kw": "manubot.cite.curie.Handler_CURIE",
    "uniprot.location": "manubot.cite.curie.Handler_CURIE",
    "uniprot.proteome": "manubot.cite.curie.Handler_CURIE",
    "uniprot.ptm": "manubot.cite.curie.Handler_CURIE",
    "uniprot.resource": "manubot.cite.curie.Handler_CURIE",
    "uniprot.taxonomy": "manubot.cite.curie.Handler_CURIE",
    "uniprot.tissue": "manubot.cite.curie.Handler_CURIE",
    "uniprot.var": "manubot.cite.curie.Handler_CURIE",
    "uniprotkb": "manubot.cite.curie.Handler_CURIE",
    "uniprotkb-kw": "manubot.cite.curie.Handler_CURIE",
    "uniprotkb-subcell": "manubot.cite.curie.Handler_CURIE",
    "uniprotkb_var": "manubot.cite.curie.Handler_CURIE",
    "uniref": "manubot.cite.curie.Handler_CURIE",
    "unirule": "manubot.cite.curie.Handler_CURIE",
    "unists": "manubot.cite.curie.Handler_CURIE",
    "unite": "manubot.cite.curie.Handler_CURIE",
    "uo": "manubot.cite.curie.Handler_CURIE",
    "up": "manubot.cite.curie.Handler_CURIE",
    "upa": "manubot.cite.curie.Handler_CURIE",
    "upheno": "manubot.cite.curie.Handler_CURIE",
    "upiso": "manubot.cite.curie.Handler_CURIE",
    "uploc": "manubot.cite.curie.Handler_CURIE",
    "uppro": "manubot.cite.curie.Handler_CURIE",
    "upvar": "manubot.cite.curie.Handler_CURIE",
    "url": "manubot.cite.url.Handler_URL",
    "uspto": "manubot.cite.curie.Handler_CURIE",
    "vac": "manubot.cite.curie.Handler_CURIE",
    "validatordb": "manubot.cite.curie.Handler_CURIE",
    "vandf": "manubot.cite.curie.Handler_CURIE",
    "vann": "manubot.cite.curie.Handler_CURIE",
    "vario": "manubot.cite.curie.Handler_CURIE",
    "vbase2": "manubot.cite.curie.Handler_CURIE",
    "vbo": "manubot.cite.curie.Handler_CURIE",
    "vbrc": "manubot.cite.curie.Handler_CURIE",
    "vcell": "manubot.cite.curie.Handler_CURIE",
    "vectorbase": "manubot.cite.curie.Handler_CURIE",
    "vega": "manubot.cite.curie.Handler_CURIE",
    "vegbank": "manubot.cite.curie.Handler_CURIE",
    "vfb": "manubot.cite.curie.Handler_CURIE",
    "vfdb.gene": "manubot.cite.curie.Handler_CURIE",
    "vfdb.genus": "manubot.cite.curie.Handler_CURIE",
    "vgnc": "manubot.cite.curie.Handler_CURIE",
    "vhog": "manubot.cite.curie.Handler_CURIE",
    "vhog_retired": "manubot.cite.curie.Handler_CURIE",
    "viaf": "manubot.cite.curie.Handler_CURIE",
    "vido": "manubot.cite.curie.Handler_CURIE",
    "violinid": "manubot.cite.curie.Handler_CURIE",
    "violinnet": "manubot.cite.curie.Handler_CURIE",
    "vipr": "manubot.cite.curie.Handler_CURIE",
    "viralzone": "manubot.cite.curie.Handler_CURIE",
    "virmirdb": "manubot.cite.curie.Handler_CURIE",
    "virsirna": "manubot.cite.curie.Handler_CURIE",
    "virushostdb": "manubot.cite.curie.Handler_CURIE",
    "vmhgene": "manubot.cite.curie.Handler_CURIE",
    "vmhmetabolite": "manubot.cite.curie.Handler_CURIE",
    "vmhreaction": "manubot.cite.curie.Handler_CURIE",
    "vo": "manubot.cite.curie.Handler_CURIE",
    "void": "manubot.cite.curie.Handler_CURIE",
    "vsao": "manubot.cite.curie.Handler_CURIE",
    "vsao_retired": "manubot.cite.curie.Handler_CURIE",
    "vsdb": "manubot.cite.curie.Handler_CURIE",
    "vsmo": "manubot.cite.curie.Handler_CURIE",
    "vso": "manubot.cite.curie.Handler_CURIE",
    "vt": "manubot.cite.curie.Handler_CURIE",
    "vto": "manubot.cite.curie.Handler_CURIE",
    "vz": "manubot.cite.curie.Handler_CURIE",
    "wb": "manubot.cite.curie.Handler_CURIE",
    "wb.rnai": "manubot.cite.curie.Handler_CURIE",
    "wb_ref": "manubot.cite.curie.Handler_CURIE",
    "wbbt": "manubot.cite.curie.Handler_CURIE",
    "wbls": "manubot.cite.curie.Handler_CURIE",
    "wbphenotype": "manubot.cite.curie.Handler_CURIE",
    "wd": "manubot.cite.curie.Handler_CURIE",
    "wd_entity": "manubot.cite.curie.Handler_CURIE",
    "webelements": "manubot.cite.curie.Handler_CURIE",
    "wgs84": "manubot.cite.curie.Handler_CURIE",
    "wicell": "manubot.cite.curie.Handler_CURIE",
    "wikidata": "manubot.cite.wikidata.Handler_Wikidata",
    "wikidata.property": "manubot.cite.curie.Handler_CURIE",
    "wikigenes": "manubot.cite.curie.Handler_CURIE",
    "wikipathways": "manubot.cite.curie.Handler_CURIE",
    "wikipedia": "manubot.cite.curie.Handler_CURIE",
    "wikipedia.en": "manubot.cite.curie.Handler_CURIE",
    "worfdb": "manubot.cite.curie.Handler_CURIE",
    "world2dpage": "manubot.cite.curie.Handler_CURIE",
    "wormbase": "manubot.cite.curie.Handler_CURIE",
    "wormpep": "manubot.cite.curie.Handler_CURIE",
    "worms": "manubot.cite.curie.Handler_CURIE",
    "wwf": "manubot.cite.curie.Handler_CURIE",
    "wwf.ecoregion": "manubot.cite.curie.Handler_CURIE",
    "wwpdb": "manubot.cite.curie.Handler_CURIE",
    "xao": "manubot.cite.curie.Handler_CURIE",
    "xco": "manubot.cite.curie.Handler_CURIE",
    "xenbase": "manubot.cite.curie.Handler_CURIE",
    "ximbio": "manubot.cite.curie.Handler_CURIE",
    "xl": "manubot.cite.curie.Handler_CURIE",
    "xlmod": "manubot.cite.curie.Handler_CURIE",
    "xmetdb": "manubot.cite.curie.Handler_CURIE",
    "xml": "manubot.cite.curie.Handler_CURIE",
    "xpo": "manubot.cite.curie.Handler_CURIE",
    "xsd": "manubot.cite.curie.Handler_CURIE",
    "ydpm": "manubot.cite.curie.Handler_CURIE",
    "yeastintron": "manubot.cite.curie.Handler_CURIE",
    "yeastract": "manubot.cite.curie.Handler_CURIE",
    "yetfasco": "manubot.cite.curie.Handler_CURIE",
    "ygob": "manubot.cite.curie.Handler_CURIE",
    "yid": "manubot.cite.curie.Handler_CURIE",
    "ymdb": "manubot.cite.curie.Handler_CURIE",
    "ypo": "manubot.cite.curie.Handler_CURIE",
    "yrcpdr": "manubot.cite.curie.Handler_CURIE",
    "zea": "manubot.cite.curie.Handler_CURIE",
    "zeco": "manubot.cite.curie.Handler_CURIE",
    "zenodo": "manubot.cite.curie.Handler_CURIE",
    "zenodo.record": "manubot.cite.curie.Handler_CURIE",
    "zfa": "manubot.cite.curie.Handler_CURIE",
    "zfa_retired": "manubot.cite.curie.Handler_CURIE",
    "zfin": "manubot.cite.curie.Handler_CURIE",
    "zfs": "manubot.cite.curie.Handler_CURIE",
    "zinc": "manubot.cite.curie.Handler_CURIE",
    "zp": "manubot.cite.curie.Handler_CURIE",
}



import logging
import shutil
import tempfile
from pathlib import Path


def cli_process(args):
    from manubot_ai_editor import models
    from manubot_ai_editor.editor import ManuscriptEditor

    # set paths for content
    content_dir = args.content_directory
    if not content_dir.is_dir():
        raise SystemExit(
            f"content directory is not a directory or does not exist: {content_dir}"
        )

    # set paths for temporary output
    tmp_dir = Path(tempfile.mkdtemp(suffix="_manubot_ai_revision"))
    logging.info(f"using temporary directory: {tmp_dir}")

    # create a manuscript editor and model to revise
    me = ManuscriptEditor(
        content_dir=content_dir,
    )

    # instantiate a model
    module_class = getattr(models, args.model_type)

    if module_class == models.GPT3CompletionModel:
        model = module_class(
            title=me.title,
            keywords=me.keywords,
        )
    else:
        model_kwargs = parse_kwargs(args.model_kwargs)

        model = module_class(
            **model_kwargs,
        )

    # revise
    me.revise_manuscript(tmp_dir, model, debug=True)

    # copy the revised manuscript back to the content folder
    for f in tmp_dir.glob("*"):
        shutil.copyfile(f, content_dir / f.name)


def parse_kwargs(kwargs: list[str]) -> dict[str, object]:
    """
    Parse a list of keyword arguments into a dictionary. Values are converted to int or bool if possible.

    Args:
        kwargs: A list of keyword arguments with format "key=value".

    Returns:
        A dictionary of keyword arguments. Returns an empty dictionary if kwargs is None.
    """
    out = {}

    if kwargs is None:
        return out

    for kwarg in kwargs:
        if "=" not in kwarg:
            raise ValueError(f"Invalid keyword argument: {kwarg}")

        key, value = kwarg.split("=", maxsplit=1)

        # try to convert values to int or bool if possible
        if value.isdigit():
            value = int(value)
        elif value.lower() in ["true", "false"]:
            value = value.lower() == "true"

        out[key] = value

    return out



import dataclasses
import json
import logging
import os
import pathlib
import typing as tp

from manubot.cite.citekey import CiteKey, citekey_to_csl_item


@dataclasses.dataclass
class Citations:
    """
    Class for operating on a set of citations provided by
    their citekey input_ids.
    """

    # Input citekey IDs as strings
    input_ids: list
    # Citation key aliases
    aliases: dict = dataclasses.field(default_factory=dict)
    # infer prefixes for citekeys (e.g. support DOIs without a "doi:" prefix)
    infer_citekey_prefixes: bool = True
    # manual references dictionary of standard_id to CSL_Item.
    manual_refs: dict = dataclasses.field(default_factory=dict)
    # level to log failures related to CSL Item generation
    csl_item_failure_log_level: tp.Union[str, int] = "WARNING"
    # whether to prune csl items according to the JSON Schema
    prune_csl_items: bool = True
    # whether to sort csl items by standard_id
    # `sort_csl_items=False` retains order of input_ids in get_csl_items.
    # (input_ids with the same standard_id will still be deduplicated).
    sort_csl_items: bool = True

    def __post_init__(self):
        input_ids = list(dict.fromkeys(self.input_ids))  # deduplicate
        self.citekeys = [
            CiteKey(x, aliases=self.aliases, infer_prefix=self.infer_citekey_prefixes)
            for x in input_ids
        ]

    def filter_pandoc_xnos(self) -> list:
        """
        Filter self.citekeys to remove pandoc-xnos style citekeys.
        Return removed citekeys.
        """
        keep, remove = [], []
        for citekey in self.citekeys:
            remove_ = citekey.is_pandoc_xnos_prefix(log_case_warning=True)
            (keep, remove)[remove_].append(citekey)
        self.citekeys = keep
        return remove

    def filter_unhandled(self) -> list:
        """
        Filter self.citekeys to remove unhandled citekeys.
        Return removed citekeys.
        """
        keep, remove = [], []
        for citekey in self.citekeys:
            (remove, keep)[citekey.is_handled_prefix].append(citekey)
        self.citekeys = keep
        return remove

    def group_citekeys_by(
        self,
        attribute: str = "standard_id",
        sort: bool = True,
    ) -> tp.List[tp.Tuple[str, list]]:
        """
        Group `self.citekeys` by `attribute`.
        """

        def get_key(x):
            return getattr(x, attribute)

        key_to_indices = {}
        for i, citekey in enumerate(self.citekeys):
            key = get_key(citekey)
            key_to_indices.setdefault(key, []).append(i)
        items = list(key_to_indices.items())
        if sort:
            items.sort(key=lambda item: item[0])
        return [(key, [self.citekeys[i] for i in indices]) for key, indices in items]

    def unique_citekeys_by(self, attribute: str = "standard_id") -> list:
        return [citekeys[0] for key, citekeys in self.group_citekeys_by(attribute)]

    def check_collisions(self):
        """
        Check for short_id hash collisions
        """
        for short_id, citekeys in self.group_citekeys_by("short_id"):
            standard_ids = sorted({x.standard_id for x in citekeys})
            if len(standard_ids) == 1:
                continue
            logging.error(
                "Congratulations! Hash collision. Please report to https://git.io/JfuhH.\n"
                f"Multiple standard_ids hashed to {short_id}: {standard_ids}"
            )

    def check_multiple_input_ids(self):
        """
        Identify different input_ids referring to the same reference.
        """
        for standard_id, citekeys in self.group_citekeys_by("standard_id"):
            input_ids = [x.input_id for x in citekeys]
            if len(input_ids) < 2:
                continue
            logging.warning(
                f"Multiple citekey input_ids refer to the same standard_id {standard_id}:\n{input_ids}"
            )

    def inspect(self, log_level=None):
        """
        If log_level is not None, log combined inspection report at this level.
        """
        citekeys = self.unique_citekeys_by("dealiased_id")
        reports = []
        for citekey in citekeys:
            report = citekey.inspect()
            if not report:
                continue
            reports.append(f"{citekey.dealiased_id} -- {report}")
        report = "\n".join(reports)
        if reports and log_level is not None:
            log_level = logging._checkLevel(log_level)
            msg = f"Inspection of dealiased citekeys revealed potential problems:\n{report}"
            logging.log(log_level, msg)
        return report

    def load_manual_references(self, *args, **kwargs):
        """
        Load manual references
        """
        from manubot.process.bibliography import load_manual_references

        manual_refs = load_manual_references(*args, **kwargs)
        self.manual_refs.update(manual_refs)

    def get_csl_items(self) -> tp.List:
        """
        Produce a list of CSL_Items. I.e. a references list / bibliography
        for `self.citekeys`.
        """
        # dictionary of input_id to CSL_Item ID (i.e. short_id),
        # excludes standard_ids for which CSL Items could not be generated.
        self.input_to_csl_id = {}
        self.csl_items = []
        for _standard_id, citekeys in self.group_citekeys_by(
            "standard_id", sort=self.sort_csl_items
        ):
            csl_item = citekey_to_csl_item(
                citekey=citekeys[0],
                prune=self.prune_csl_items,
                log_level=self.csl_item_failure_log_level,
                manual_refs=self.manual_refs,
            )
            if csl_item:
                for ck in citekeys:
                    self.input_to_csl_id[ck.input_id] = csl_item["id"]
                self.csl_items.append(csl_item)
        return self.csl_items

    @property
    def citekeys_tsv(self) -> str:
        import csv
        import io

        fields = ["input_id", "dealiased_id", "standard_id", "short_id"]
        output = io.StringIO()
        writer = csv.DictWriter(output, fieldnames=fields, delimiter="\t")
        writer.writeheader()
        for citekey in self.citekeys:
            row = {x: getattr(citekey, x) for x in fields}
            writer.writerow(row)
        return output.getvalue()

    @property
    def csl_json(self) -> str:
        assert hasattr(self, "csl_items")
        json_str = json.dumps(self.csl_items, indent=2, ensure_ascii=False)
        json_str += "\n"
        return json_str

    @property
    def csl_yaml(self) -> str:
        from manubot.util import get_configured_yaml

        yaml = get_configured_yaml()
        assert hasattr(self, "csl_items")
        # dump rather than safe_dump is required for
        # pyyaml to use custom representers.
        return yaml.dump(
            data=self.csl_items,
            default_flow_style=False,
            width=float("inf"),
            allow_unicode=True,
            sort_keys=False,
        )

    def write_csl_items(self, path: tp.Union[os.PathLike, str, None]) -> None:
        """
        Write CSL Items to a JSON or YAML file at `path`.
        If path ends with a .yml or .yaml extension, write as CSL YAML.
        Otherwise write CSL JSON.
        If `path` evaluates as False, do nothing.
        """
        if not path:
            return
        path = pathlib.Path(path)
        text = self.csl_yaml if path.suffix in [".yaml", ".yml"] else self.csl_json
        path.write_text(text, encoding="utf-8")

    def write_citekeys_tsv(self, path: tp.Union[os.PathLike, str, None]):
        """
        Write `self.citekeys_tsv` to a file.
        If `path` evaluates as False, do nothing.
        """
        if not path:
            return
        path = pathlib.Path(path)
        path.write_text(self.citekeys_tsv, encoding="utf-8")
